@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -36,7 +36,7 @@
 #include "gui_savedialog.h"
 #include "gui_utils.h"
 #include "support.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "utils.h"
 #include "log.h"
 #include "hamlib-utils.h"
@@ -53,6 +53,8 @@ extern GtkWidget *mainnotebook;
 extern preferencestype preferences;
 extern GList *logwindowlist;
 extern GtkUIManager *ui_manager;
+extern GtkPageSetup *print_page_setup;
+extern GtkPrintSettings *print_settings;
 
 /* get the action name and use it to switch logs <alt>1, <alt>2, etc. */
 void 
@@ -68,6 +70,20 @@ on_menu_log_activate (GtkAction *action, gpointer user_data)
 }
 
 
+void
+on_menu_pagesetup_activate (GtkAction *action, gpointer user_data)
+{
+	GtkPageSetup *new_page_setup;
+
+	if (print_settings == NULL)
+		print_settings = gtk_print_settings_new ();
+	new_page_setup = gtk_print_run_page_setup_dialog
+		(GTK_WINDOW (mainwindow), print_page_setup, print_settings);
+	if (print_page_setup)
+		g_object_unref (print_page_setup);
+	print_page_setup = new_page_setup;
+}
+
 void
 on_menu_exit_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
@@ -96,18 +112,13 @@ on_menu_exit_activate (GtkMenuItem * menuitem, gpointer user_data)
 void
 on_menu_save_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	gchar *temp;
-	logtype *logwindow;
-	gint page;
-
-	page = gtk_notebook_get_current_page (GTK_NOTEBOOK(mainnotebook));
+	gint page = gtk_notebook_get_current_page (GTK_NOTEBOOK(mainnotebook));
 	if (page >= 0)
 	{
-		logwindow = g_list_nth_data (logwindowlist, page);
+		logtype *logwindow = g_list_nth_data (logwindowlist, page);
 		savelog (logwindow, logwindow->filename, TYPE_FLOG, 1 , logwindow->qsos);
-		temp = g_strdup_printf (_("Log saved to %s"), logwindow->filename);
+		gchar *temp = g_strdup_printf (_("Log saved to %s"), logwindow->filename);
 		update_statusbar (temp);
-		g_free (temp);
 		logwindow->logchanged = FALSE;
 		temp = g_strdup_printf ("<b>%s</b>", logwindow->logname);
 		gtk_label_set_markup (GTK_LABEL (logwindow->label), temp);
@@ -193,7 +204,6 @@ on_clearframe_activate (GtkMenuItem * menuitem, gpointer user_data)
 	}
 
 	/* Update (clear) Awards */
-
 	guint st, zone, cont, iota;
 	gchar *aw = gtk_editable_get_chars (GTK_EDITABLE (awardsentry), 0, -1);
 	gchar *result = valid_awards_entry (aw,  &st, &zone, &cont, &iota);
@@ -222,7 +232,7 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 		*bandoptionmenu, *modeoptionmenu;
 	GtkTextBuffer *b;
 	guint c, bandenum, modeenum;
-	gchar *countstr, *str;
+	gchar *countstr, *lastmsg, *str;
 	GtkWidget *mhzbutton, *modebutton, *rstbutton, *powerbutton;
 
 	datebutton = lookup_widget (mainwindow, "datebutton");
@@ -280,7 +290,7 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 	}
 	else
 	{
- 		if (g_ascii_strcasecmp (preferences.defaultmhz, "?"))
+ 		if (strlen (preferences.defaultmhz) > 0)
 		{
  			if (strlen(gtk_editable_get_chars (GTK_EDITABLE (bandentry), 0, -1)) == 0)
  				gtk_entry_set_text (GTK_ENTRY (bandentry), preferences.defaultmhz);
@@ -288,7 +298,7 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 			activate_bandoption_by_enum
                                 (bandoptionmenu, preferences.bands, bandenum);
 		}
- 		if (g_ascii_strcasecmp (preferences.defaultmode, "?"))
+ 		if (strlen (preferences.defaultmode) > 0)
 		{
  			if (strlen(gtk_editable_get_chars (GTK_EDITABLE (modeentry), 0, -1)) == 0)
  				gtk_entry_set_text (GTK_ENTRY (modeentry), preferences.defaultmode);
@@ -297,7 +307,7 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 			activate_modeoption_by_enum
 				(modeoptionmenu, preferences.modes, modeenum);
 		}
-		if (g_ascii_strcasecmp (preferences.defaulttxrst, "?"))
+		if (strlen (preferences.defaulttxrst) > 0)
 			if (strlen(gtk_editable_get_chars (GTK_EDITABLE (rstentry), 0, -1)) == 0)
 			{
 				if (keyerwindow && g_strrstr (preferences.defaulttxrst, "#"))
@@ -315,10 +325,18 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 					gtk_entry_set_text (GTK_ENTRY (rstentry), str);
 					g_free (str);
 				}
+				else if (keyerwindow && g_strrstr (preferences.defaulttxrst, "~"))
+				{
+					lastmsg = get_last_msg ();
+					str = my_strreplace (preferences.defaulttxrst, "~", lastmsg);
+					g_free (lastmsg);
+					gtk_entry_set_text (GTK_ENTRY (rstentry), str);
+					g_free (str);
+				}
 				else
 					gtk_entry_set_text (GTK_ENTRY (rstentry), preferences.defaulttxrst);
 			}
-		if (GTK_WIDGET_VISIBLE (powerhbox) && g_ascii_strcasecmp (preferences.defaultpower, "?"))
+		if (GTK_WIDGET_VISIBLE (powerhbox) && strlen (preferences.defaultpower) > 0)
 		{
 			if (strlen(gtk_editable_get_chars (GTK_EDITABLE (powerentry), 0, -1)) == 0)
 				gtk_entry_set_text (GTK_ENTRY (powerentry), preferences.defaultpower);
@@ -326,34 +344,34 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 	}
 
 	/* set non-hamlib defaults */
-	if (g_ascii_strcasecmp (preferences.defaultrxrst, "?"))
+	if (strlen (preferences.defaultrxrst) > 0)
 	{
 		myrstentry = lookup_widget (mainwindow, "myrstentry");
 		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (myrstentry), 0, -1)) == 0)
 			gtk_entry_set_text (GTK_ENTRY (myrstentry), preferences.defaultrxrst);
 	}
-	if (g_ascii_strcasecmp (preferences.defaultawards, "?"))
+	if (strlen (preferences.defaultawards) > 0)
 	{
 		awardsentry = lookup_widget (mainwindow, "awardsentry");
 		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (awardsentry), 0, -1)) == 0)
 			gtk_entry_set_text (GTK_ENTRY (awardsentry), preferences.defaultawards);
 	}
 	unknown1hbox = lookup_widget (mainwindow, "unknown1hbox");
-	if (GTK_WIDGET_VISIBLE (unknown1hbox)	&& g_ascii_strcasecmp (preferences.defaultfreefield1, "?"))
+	if (GTK_WIDGET_VISIBLE (unknown1hbox)	&& strlen (preferences.defaultfreefield1) > 0)
 	{
 		unknownentry1 = lookup_widget (mainwindow, "unknownentry1");
 		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (unknownentry1), 0, -1)) == 0)
 			gtk_entry_set_text (GTK_ENTRY (unknownentry1), preferences.defaultfreefield1);
 	}
 	unknown2hbox = lookup_widget (mainwindow, "unknown2hbox");
-	if (GTK_WIDGET_VISIBLE (unknown2hbox)	&& g_ascii_strcasecmp (preferences.defaultfreefield2, "?"))
+	if (GTK_WIDGET_VISIBLE (unknown2hbox)	&& strlen (preferences.defaultfreefield2) > 0)
 	{
 		unknownentry2 = lookup_widget (mainwindow, "unknownentry2");
 		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (unknownentry2), 0, -1)) == 0)
 			gtk_entry_set_text (GTK_ENTRY (unknownentry2), preferences.defaultfreefield2);
 	}
 	remarksvbox = lookup_widget (mainwindow, "remarksvbox");
-	if (GTK_WIDGET_VISIBLE (remarksvbox) && g_ascii_strcasecmp (preferences.defaultremarks, "?"))
+	if (GTK_WIDGET_VISIBLE (remarksvbox) && strlen (preferences.defaultremarks) > 0)
 	{
 		remtv = lookup_widget (mainwindow, "remtv");
 		b = gtk_text_view_get_buffer (GTK_TEXT_VIEW (remtv));
@@ -361,8 +379,6 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 			gtk_text_buffer_set_text (b, preferences.defaultremarks, -1);
 	}
 
-	unselect_logs ();
-
 	callentry = lookup_widget (mainwindow, "callentry");
 	gtk_widget_grab_focus (callentry);
 	gtk_editable_set_position (GTK_EDITABLE(callentry), -1);
@@ -374,7 +390,7 @@ on_addclickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 	GtkWidget *clickallmenu, *abutton;
 
 	abutton = gtk_ui_manager_get_widget
-		(ui_manager, "/ToolBar/Add");
+		(ui_manager, "/ToolBar/Write");
 	g_signal_emit_by_name (G_OBJECT (abutton), "clicked");
 	clickallmenu = gtk_ui_manager_get_widget
 		(ui_manager, "/MainMenu/EditMenu/Click All");
