@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -32,7 +32,7 @@
 #include "callbacks_mainwindow_toolbar.h"
 #include "callbacks_mainwindow_menu.h"
 #include "support.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "log.h"
 #include "xlog_enum.h"
 #include "awards_enum.h"
@@ -42,7 +42,7 @@
 #include "wwl.h"
 #include "hamlib-utils.h"
 
-extern GtkWidget *mainwindow, *scorewindow, *keyerwindow;
+extern GtkWidget *mainwindow, *scorewindow, *keyerwindow, *locatormap;
 extern GtkWidget *mainnotebook;
 extern preferencestype preferences;
 extern gchar **bandsplit;
@@ -282,7 +282,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 				lookup = lookupcountry_by_callsign (qso[CALL]);
 			f = freq2enum (qso[BAND]);
 			gboolean qslconfirmed = qslreceived (qso[QSLIN]);
-			if (preferences.scoringbands[f] == '1')
+			if (preferences.scoringbands[f] == 1)
 			{
 				if (lookup.country > 0)
 				{
@@ -340,20 +340,37 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 				if (iota != NOT_AN_IOTA)
 				{
 					iota_new_qso(iota, f, qslconfirmed);
-					/* TODO: update_iotascoring only upon w/c */
 					if ((preferences.awardsiota == 1))
 						update_iotascoring ();
 				}
 				if (qso[LOCATOR] && (strlen(qso[LOCATOR]) > 0))
 				{
 					loc_new_qso(qso[LOCATOR], f, qslconfirmed);
-					/* TODO: update_locscoring only upon w/c */
 					if ((preferences.awardsloc == 1))
 						update_locscoring ();
 				}
-			/* check if this is a new country and update scoring */
 			}
 		}
+		else
+		{
+			if (locatormap)
+			{
+				if (qso[LOCATOR] && (strlen(qso[LOCATOR]) > 0))
+				{
+					gboolean qslconfirmed = qslreceived (qso[QSLIN]);
+					f = freq2enum (qso[BAND]);
+					loc_new_qso(qso[LOCATOR], f, qslconfirmed);
+					if ((preferences.awardsloc == 1))
+						update_locscoring ();
+				}
+			}
+		}
+
+		if (locatormap)
+		{
+			GtkWidget *da= lookup_widget (locatormap, "drawingarea");
+			g_signal_emit_by_name(da, "configure_event");
+		}
 
 		if (preferences.saving == 2)
 		{
@@ -511,7 +528,7 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 				lookup = lookupcountry_by_callsign (call);
 
 				f = freq2enum (freq);
-				if (preferences.scoringbands[f] == '1')
+				if (preferences.scoringbands[f] == 1)
 				{
 					if (lookup.country > 0)
 					{
@@ -571,19 +588,36 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 					if (iota != NOT_AN_IOTA)
 					{
 						iota_del_qso(iota, f, qslin);
-						/* TODO: update_iotascoring only upon w/c */
 						if ((preferences.awardsiota == 1))
 							update_iotascoring ();
 					}
 					if (locator && (strlen(locator) > 0))
 					{
 						loc_del_qso(locator, f, qslin);
-						/* TODO: update_locscoring only upon w/c */
 						if ((preferences.awardsloc == 1))
 							update_locscoring ();
 					}
 				}
 			}
+			else
+			{
+				if (locatormap)
+				{
+					if (qso[LOCATOR] && (strlen(qso[LOCATOR]) > 0))
+					{
+						gboolean qslconfirmed = qslreceived (qso[QSLIN]);
+						f = freq2enum (qso[BAND]);
+						loc_new_qso(qso[LOCATOR], f, qslconfirmed);
+						if ((preferences.awardsloc == 1))
+							update_locscoring ();
+					}
+				}
+			}
+			if (locatormap)
+			{
+				GtkWidget *da= lookup_widget (locatormap, "drawingarea");
+				g_signal_emit_by_name(da, "configure_event");
+			}
 			if (preferences.saving == 2)
 			{
 				savelog (logw, logw->filename, TYPE_FLOG, 1, logw->qsos);
@@ -615,7 +649,8 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 	GtkTextIter start, end;
 	gint bandindex, modeindex, i = 0, page, fr, froption, result, kms, l;
 	guint st, zone, cont, iota;
-	gchar *temp, *label, *logcall, *logfreq, *logqslin, *logawards, *logtime, *logendtime;
+	gchar *temp, *label, *logcall, *logfreq, *logqslin, *logawards, *logtime,
+		*logendtime, *loglocator;
 	logtype *logw;
 	GtkTreeIter selected;
 	GtkTreeModel *model;
@@ -645,6 +680,10 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 		for (i = 0; i < QSO_FIELDS; i++)
 			qso[i] = g_strdup ("");
 
+		/* now retrieve new logdata from the qsoframe, we need to keep the
+		 * call, frequency, qslin, awards and locator from the log to update
+		 * scoring and/or the locator map further down */
+
 		if (gtk_tree_selection_get_selected (gtk_tree_view_get_selection
 			(GTK_TREE_VIEW(logw->treeview)), &model, &selected))
 		{
@@ -758,6 +797,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			locatorhbox = lookup_widget (mainwindow, "locatorhbox");
 			if (GTK_WIDGET_VISIBLE (locatorhbox))
 			{
+				gtk_tree_model_get (model, &selected, LOCATOR, &loglocator, -1);
 				locatorentry = lookup_widget (mainwindow, "locatorentry");
 				qso[LOCATOR] = gtk_editable_get_chars (GTK_EDITABLE (locatorentry), 0, -1);
 				gtk_editable_delete_text (GTK_EDITABLE (locatorentry), 0, -1);
@@ -852,7 +892,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 
 				fr = freq2enum (logfreq);
 				qslconfirmed = qslreceived (logqslin);
-				if (preferences.scoringbands[fr] == '1')
+				if (preferences.scoringbands[fr] == 1)
 				{
 					if (lookup.country > 0)
 					{
@@ -899,7 +939,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 					if (iota != NOT_AN_IOTA)
 						iota_del_qso(iota, fr, qslconfirmed);
 					if (qso[LOCATOR] && (strlen(qso[LOCATOR]) > 0))
-						loc_del_qso(qso[LOCATOR], fr, qslconfirmed);
+						loc_del_qso(loglocator, fr, qslconfirmed);
 				}
 
 				result = valid_awards_entry (qso[AWARDS], &st, &zone, &cont, &iota);
@@ -913,7 +953,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 
 				fr = freq2enum (qso[BAND]);
 				qslconfirmed = qslreceived (qso[QSLIN]);
-				if (preferences.scoringbands[fr] == '1')
+				if (preferences.scoringbands[fr] == 1)
 				{
 					if (lookup.country > 0)
 					{
@@ -971,6 +1011,28 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 				if (preferences.awardsiota == 1) update_iotascoring ();
 				if (preferences.awardsloc == 1) update_locscoring ();
 			}
+			else
+			{
+				if (locatormap)
+				{
+					if (qso[LOCATOR] && (strlen(qso[LOCATOR]) > 0))
+					{
+						gboolean qslconfirmed = qslreceived (logqslin);
+						fr = freq2enum (logfreq);
+						loc_del_qso(loglocator, fr, qslconfirmed);
+						fr = freq2enum (qso[BAND]);
+						qslconfirmed = qslreceived (qso[QSLIN]);
+						loc_new_qso(qso[LOCATOR], fr, qslconfirmed);
+						if ((preferences.awardsloc == 1))
+							update_locscoring ();
+					}
+				}
+			}
+			if (locatormap)
+			{
+				GtkWidget *da= lookup_widget (locatormap, "drawingarea");
+				g_signal_emit_by_name(da, "configure_event");
+			}
 
 			g_free (logcall);
 			g_free (logfreq);
