@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -59,7 +59,7 @@ gcircle (gint units, gdouble latmy, gdouble lonmy, gdouble latdx, gdouble londx)
 		unitsstr = g_strdup ("m");
 
 	/* data in cty.dat uses a negative number for eastern longitudes */
-	retcode = qrb (lonmy, latmy, -1 * londx, latdx, &distsp, &bsp);
+	retcode = qrb (lonmy, latmy, (-1. * londx), latdx, &distsp, &bsp);
 	if (retcode == RIG_OK)
 	{
 		distlp = distance_long_path (distsp);
