@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -28,18 +28,21 @@
 #include "support.h"
 #include "xlog_enum.h"
 #include "awards_enum.h"
-#include "preferences.h"
+#include "cfg.h"
 
-extern GtkWidget *mainwindow;
+extern GtkWidget *mainwindow, *scorewindow;
 extern preferencestype preferences;
 extern gushort wac_w[MAX_CONTINENTS][MAX_BANDS + 1];
 extern gushort wac_c[MAX_CONTINENTS][MAX_BANDS + 1];
 
 void on_awards_wac_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
+	if (!GTK_WIDGET_VISIBLE(scorewindow))
+		warningdialog (_("xlog - WAC award"),
+			_("Please enable the scoring window"), "gtk-dialog-warning");
 	if (preferences.awardswac == 0)
 	{
-		warningdialog (_("xlog - WAC awards"),
+		warningdialog (_("xlog - WAC award"),
                         _("You will need to enable WAC scoring from the \"windows and dialogs\" dialog"), "gtk-dialog-warning");
 		return;
 	}
@@ -55,7 +58,7 @@ void on_awards_wac_activate (GtkMenuItem *menuitem, gpointer user_data)
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow),
 		GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	/* 2 extra columns, continent and 'all bands */
-	GtkListStore *model = gtk_list_store_new (MAX_BANDS + 2,
+	GtkListStore *model = gtk_list_store_new (MAX_BANDS + 1,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
@@ -63,7 +66,7 @@ void on_awards_wac_activate (GtkMenuItem *menuitem, gpointer user_data)
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+		G_TYPE_STRING, G_TYPE_STRING);
 	GtkWidget *treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(model));
 	g_object_unref (G_OBJECT (model));
 	gtk_container_add (GTK_CONTAINER (scrolledwindow), treeview);
@@ -75,151 +78,147 @@ void on_awards_wac_activate (GtkMenuItem *menuitem, gpointer user_data)
 		("0.137", renderer, "text", BAND_2190 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_2190] - 48);
+                (column, preferences.scoringbands[BAND_2190]);
 	column = gtk_tree_view_column_new_with_attributes
 		("1.8", renderer, "text", BAND_160 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_160] - 48);
+                (column, preferences.scoringbands[BAND_160]);
 	column = gtk_tree_view_column_new_with_attributes
 		("3.5", renderer, "text", BAND_80 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_80] - 48);
+                (column, preferences.scoringbands[BAND_80]);
 	column = gtk_tree_view_column_new_with_attributes
 		("5.3", renderer, "text", BAND_60 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_60] - 48);
+                (column, preferences.scoringbands[BAND_60]);
 	column = gtk_tree_view_column_new_with_attributes
 		("7", renderer, "text", BAND_40 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_40] - 48);
+                (column, preferences.scoringbands[BAND_40]);
 	column = gtk_tree_view_column_new_with_attributes
 		("10", renderer, "text", BAND_30 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_30] - 48);
+                (column, preferences.scoringbands[BAND_30]);
 	column = gtk_tree_view_column_new_with_attributes
 		("14", renderer, "text", BAND_20 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_20] - 48);
+                (column, preferences.scoringbands[BAND_20]);
 	column = gtk_tree_view_column_new_with_attributes
 		("18", renderer, "text", BAND_17 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_17] - 48);
+                (column, preferences.scoringbands[BAND_17]);
 	column = gtk_tree_view_column_new_with_attributes
 		("21", renderer, "text", BAND_15 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_15] - 48);
+                (column, preferences.scoringbands[BAND_15]);
 	column = gtk_tree_view_column_new_with_attributes
 		("24", renderer, "text", BAND_12 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_12] - 48);
+                (column, preferences.scoringbands[BAND_12]);
 	column = gtk_tree_view_column_new_with_attributes
 		("28", renderer, "text", BAND_10 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_10] - 48);
+                (column, preferences.scoringbands[BAND_10]);
 	column = gtk_tree_view_column_new_with_attributes
 		("50", renderer, "text", BAND_6 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_6] - 48);
+                (column, preferences.scoringbands[BAND_6]);
 	column = gtk_tree_view_column_new_with_attributes
 		("70", renderer, "text", BAND_4 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_4] - 48);
+                (column, preferences.scoringbands[BAND_4]);
 	column = gtk_tree_view_column_new_with_attributes
 		("144", renderer, "text", BAND_2 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_2] - 48);
+                (column, preferences.scoringbands[BAND_2]);
 	column = gtk_tree_view_column_new_with_attributes
 		("222", renderer, "text", BAND_125CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_125CM] - 48);
+                (column, preferences.scoringbands[BAND_125CM]);
 	column = gtk_tree_view_column_new_with_attributes
 		("420", renderer, "text", BAND_70CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_70CM] - 48);
+                (column, preferences.scoringbands[BAND_70CM]);
 	column = gtk_tree_view_column_new_with_attributes
 		("902", renderer, "text", BAND_33CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_33CM] - 48);
+                (column, preferences.scoringbands[BAND_33CM]);
 	column = gtk_tree_view_column_new_with_attributes
 		("1240", renderer, "text", BAND_23CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_23CM] - 48);
+                (column, preferences.scoringbands[BAND_23CM]);
 	column = gtk_tree_view_column_new_with_attributes
 		("2300", renderer, "text", BAND_13CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_13CM] - 48);
+                (column, preferences.scoringbands[BAND_13CM]);
 	column = gtk_tree_view_column_new_with_attributes
 		("3300", renderer, "text", BAND_9CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_9CM] - 48);
+                (column, preferences.scoringbands[BAND_9CM]);
 	column = gtk_tree_view_column_new_with_attributes
 		("5650", renderer, "text", BAND_6CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_6CM] - 48);
+                (column, preferences.scoringbands[BAND_6CM]);
 	column = gtk_tree_view_column_new_with_attributes
 		("10000", renderer, "text", BAND_3CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_3CM] - 48);
+                (column, preferences.scoringbands[BAND_3CM]);
 	column = gtk_tree_view_column_new_with_attributes
 		("24000", renderer, "text", BAND_12HMM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_12HMM] - 48);
+                (column, preferences.scoringbands[BAND_12HMM]);
 	column = gtk_tree_view_column_new_with_attributes
 		("47000", renderer, "text", BAND_6MM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_6MM] - 48);
+                (column, preferences.scoringbands[BAND_6MM]);
 	column = gtk_tree_view_column_new_with_attributes
 		("75500", renderer, "text", BAND_4MM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_4MM] - 48);
+                (column, preferences.scoringbands[BAND_4MM]);
 	column = gtk_tree_view_column_new_with_attributes
 		("120000", renderer, "text", BAND_2HMM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_2HMM] - 48);
+                (column, preferences.scoringbands[BAND_2HMM]);
 	column = gtk_tree_view_column_new_with_attributes
 		("142000", renderer, "text", BAND_2MM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_2MM] - 48);
+                (column, preferences.scoringbands[BAND_2MM]);
 	column = gtk_tree_view_column_new_with_attributes
 		("241000", renderer, "text", BAND_1MM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_1MM] - 48);
+                (column, preferences.scoringbands[BAND_1MM]);
 	column = gtk_tree_view_column_new_with_attributes
 		("300000", renderer, "text", BAND_SUBMM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 	gtk_tree_view_column_set_visible
-                (column, preferences.scoringbands[BAND_SUBMM] - 48);
-
-	column = gtk_tree_view_column_new_with_attributes
-		("All", renderer, "text", MAX_BANDS + 1, NULL);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
+                (column, preferences.scoringbands[BAND_SUBMM]);
 
 	GtkTreeIter iter;
 	gint i, j;
