@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -34,7 +34,7 @@
 #include "gui_utils.h"
 #include "main.h"
 #include "dxcc.h"
-#include "preferences.h"
+#include "cfg.h"
 
 extern GtkWidget *mainwindow, *scorewindow;
 extern GtkWidget *mainnotebook;
