@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -207,6 +207,9 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 		g_signal_connect ((gpointer) cancel_button, "clicked",
                     G_CALLBACK (on_dupecheckcancelbutton_clicked),
                     NULL);
+		g_signal_connect ((gpointer) dupecheckdialog, "delete_event",
+                    G_CALLBACK (on_dupecheckcancelbutton_clicked),
+                    NULL);
 
 		gtk_widget_show_all (dupecheckdialog);
 		dupecheckresponse = gtk_dialog_run (GTK_DIALOG(dupecheckdialog));
@@ -498,9 +501,5 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 				gtk_widget_destroy (duperesultdialog);
 			}
 		} /* GTK_RESPONSE_OK */
-		else if (dupecheckresponse == GTK_RESPONSE_CANCEL)
-		{
-			gtk_widget_destroy (dupecheckdialog);
-		}
 	} /* page >= 0 */
 }
