@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -33,7 +33,7 @@
 #include <gtk/gtk.h>
 #include <stdlib.h>
 
-#include "preferences.h"
+#include "cfg.h"
 #include "log.h"
 #include "gui_exportdialog.h"
 #include "support.h"
@@ -137,7 +137,7 @@ on_menu_export_activate (GtkMenuItem * menuitem, gpointer user_data)
 				gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook)));
 			if (lowqso > highqso || highqso > logwindow->qsos)
 update_statusbar(_("Cannot export log: invalid entry for first and/or last QSO"));
-			else if (!fileexist (sellog))
+			else if (!g_file_test(sellog, G_FILE_TEST_EXISTS))
 			{
 				savelog (logwindow, sellog, type, lowqso, highqso);
 				temp = g_strdup_printf (_("Log exported to %s"), sellog);
