@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -34,8 +34,11 @@
  */
 
 #include <gtk/gtk.h>
-#include <stdio.h>
 #include <string.h>
+#include <glib/gstdio.h>
+#ifdef G_OS_WIN32
+#include <stdlib.h>
+#endif
 
 #include "gui_helpdialog.h"
 #include "support.h"
@@ -76,15 +79,19 @@ static void open_help (gchar *filename)
 	gtk_container_add (GTK_CONTAINER (scrolledwindow), helptextview);
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(helptextview));
 	gtk_text_buffer_get_start_iter (buffer, &iter);
-	helpfile = g_strdup_printf ("%s%s%s", XLOG_DATADIR, G_DIR_SEPARATOR_S, 
+#ifdef G_OS_WIN32
+	helpfile = g_strdup_printf ("%s", filename);
+#else
+	helpfile = g_strdup_printf ("%s%s%s", XLOG_DOCDIR, G_DIR_SEPARATOR_S, 
 		filename);
+#endif
 	gtk_text_buffer_create_tag (buffer, "bold", "weight", PANGO_WEIGHT_BOLD, NULL);
 	gtk_text_buffer_create_tag (buffer, "italic", "style", PANGO_STYLE_ITALIC, NULL);
 	gtk_text_buffer_create_tag (buffer, "blue", "foreground", "blue", NULL);
 
 	buf = g_new0 (gchar, 100);
 	g_get_charset (&encoding);
-	in = fopen (helpfile, "r");
+	in = g_fopen (helpfile, "r");
 	if (in)
 	{
 		do 
@@ -150,10 +157,18 @@ static void open_help (gchar *filename)
 void
 on_helpmanual_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
+#ifdef G_OS_WIN32
+	gchar *win32_dir = g_win32_get_package_installation_directory_of_module (NULL);
+	gchar *command = g_strdup_printf ("iexplore.exe %s%smanual%sindex.html", win32_dir, G_DIR_SEPARATOR_S, G_DIR_SEPARATOR_S);
+	win32_fork (command);
+	g_free (win32_dir);
+	g_free (command);
+#else
 	gchar *command[] = {"xdg-open", NULL, NULL};
-	command[1] = g_strconcat (XLOG_DATADIR, G_DIR_SEPARATOR_S, "manual", G_DIR_SEPARATOR_S, "index.html", NULL);
+	command[1] = g_strconcat (XLOG_DOCDIR, G_DIR_SEPARATOR_S, "manual", G_DIR_SEPARATOR_S, "index.html", NULL);
 	g_spawn_async (NULL, command, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, NULL);
 	g_free (command[1]);
+#endif
 }
 
 
