@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -33,7 +33,7 @@
 #include <string.h>
 
 #include "support.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "log.h"
 #include "utils.h"
 #include "gui_logeditordialog.h"
@@ -53,12 +53,20 @@ compare_fields (void *f1, void *f2, gpointer user_data)
 		return (*p - *q);
 }
 
-/* update logfields and return number of columns */
+/* update logfields and return number of columns
+ * 
+ * column: column number in the log 
+ * logfields: array with visible columns
+ * showhide: 1 = hide, 0 = show 
+ */
 static void
-update_logfields (gint column, gint logfields[], gint showhide)
+update_logfields (const gint column, gint logfields[], const gint showhide)
 {
 	gint i, j;
 
+	/*
+	 * Search for the column in the logfields array
+	 */
 	for (i = 0; i < QSO_FIELDS; i++)
 	{
 		if (logfields[i] == column)
@@ -105,19 +113,6 @@ update_logfields (gint column, gint logfields[], gint showhide)
 	}
 }
 
-/* check if column width entries have changed */
-static gboolean wchanged (gpointer arg)
-{
-	gchar *temp;
-	gboolean ret = FALSE;
-
-	temp = g_strjoinv (",", arg);
-	if (g_ascii_strcasecmp (temp, preferences.logcwidths2) != 0)
-		ret = TRUE;
-	g_free (temp);
-	return ret;
-}
-
 void
 on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
@@ -145,7 +140,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		*lehbox16, *leentry16, *lecombo16, *lee16,
 		*lehbox17, *lelabel17_1, *lecombo17, *lee17;
 	logtype *logw;
-	gchar *temp, **w;
+	gchar *temp;
 	gint i, j, index, page, response, columns, fields[QSO_FIELDS];
 	GtkTreeViewColumn *column;
 
@@ -153,8 +148,6 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 	if (page >= 0)
 	{
-		w = g_strsplit(preferences.logcwidths2, ",", 0);
-
 		logeditor = gtk_dialog_new_with_buttons (_("xlog - logeditor"),
 			GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -195,7 +188,10 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		logw = g_list_nth_data (logwindowlist, page);
 		column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), NR);
 		if (gtk_tree_view_column_get_visible (column))
-			gtk_entry_set_text (GTK_ENTRY(lee0), w[NR]);
+		{
+			temp = g_strdup_printf ("%d", preferences.logcwidths2[NR]);
+			gtk_entry_set_text (GTK_ENTRY(lee0), temp);
+		}
 		else
 			gtk_entry_set_text (GTK_ENTRY(lee0), "0");
 		gtk_entry_set_activates_default (GTK_ENTRY (lee0), TRUE);
@@ -209,7 +205,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee1 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee1, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox1), lee1, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee1), w[DATE]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[DATE]);
+		gtk_entry_set_text (GTK_ENTRY(lee1), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee1), TRUE);
 
 		lehbox2 = gtk_hbox_new (TRUE, 0);
@@ -222,7 +219,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee2 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee2, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox2), lee2, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee2), w[GMT]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[GMT]);
+		gtk_entry_set_text (GTK_ENTRY(lee2), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee2), TRUE);
 
 		lehbox3 = gtk_hbox_new (TRUE, 0);
@@ -236,7 +234,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee3 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee3, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox3), lee3, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee3), w[GMTEND]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[GMTEND]);
+		gtk_entry_set_text (GTK_ENTRY(lee3), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee3), TRUE);
 
 		lehbox4 = gtk_hbox_new (TRUE, 0);
@@ -249,7 +248,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee4 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee4, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox4), lee4, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee4), w[CALL]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[CALL]);
+		gtk_entry_set_text (GTK_ENTRY(lee4), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee4), TRUE);
 
 		lehbox5 = gtk_hbox_new (TRUE, 0);
@@ -262,7 +262,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee5 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee5, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox5), lee5, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee5), w[BAND]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[BAND]);
+		gtk_entry_set_text (GTK_ENTRY(lee5), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee5), TRUE);
 
 		lehbox6 = gtk_hbox_new (TRUE, 0);
@@ -275,7 +276,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee6 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee6, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox6), lee6, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee6), w[MODE]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[MODE]);
+		gtk_entry_set_text (GTK_ENTRY(lee6), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee6), TRUE);
 
 		lehbox7 = gtk_hbox_new (TRUE, 0);
@@ -288,7 +290,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee7 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee7, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox7), lee7, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee7), w[RST]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[RST]);
+		gtk_entry_set_text (GTK_ENTRY(lee7), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee7), TRUE);
 
 		lehbox8 = gtk_hbox_new (TRUE, 0);
@@ -301,7 +304,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee8 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee8, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox8), lee8, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee8), w[MYRST]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[MYRST]);
+		gtk_entry_set_text (GTK_ENTRY(lee8), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee8), TRUE);
 
 		hboxtopright = gtk_hbox_new (TRUE, 0);
@@ -329,7 +333,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee18 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee18, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox18), lee18, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee18), w[AWARDS]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[AWARDS]);
+		gtk_entry_set_text (GTK_ENTRY(lee18), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee18), TRUE);
 
 		lehbox9_10 = gtk_hbox_new (TRUE, 0);
@@ -343,7 +348,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee9_10 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee9_10, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox9_10), lee9_10, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee9_10), w[QSLIN]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[QSLIN]);
+		gtk_entry_set_text (GTK_ENTRY(lee9_10), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee9_10), TRUE);
 
 		lehbox11 = gtk_hbox_new (TRUE, 0);
@@ -357,7 +363,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee11 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee11, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox11), lee11, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee11), w[POWER]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[POWER]);
+		gtk_entry_set_text (GTK_ENTRY(lee11), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee11), TRUE);
 
 		lehbox12 = gtk_hbox_new (TRUE, 0);
@@ -371,7 +378,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee12 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee12, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox12), lee12, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee12), w[NAME]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[NAME]);
+		gtk_entry_set_text (GTK_ENTRY(lee12), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee12), TRUE);
 
 		lehbox13 = gtk_hbox_new (TRUE, 0);
@@ -385,7 +393,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee13 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee13, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox13), lee13, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee13), w[QTH]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[QTH]);
+		gtk_entry_set_text (GTK_ENTRY(lee13), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee13), TRUE);
 
 		lehbox14 = gtk_hbox_new (TRUE, 0);
@@ -399,7 +408,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee14 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee14, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox14), lee14, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee14), w[LOCATOR]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[LOCATOR]);
+		gtk_entry_set_text (GTK_ENTRY(lee14), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee14), TRUE);
 
 		lehbox15 = gtk_hbox_new (TRUE, 0);
@@ -415,7 +425,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee15 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee15, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox15), lee15, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee15), w[U1]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[U1]);
+		gtk_entry_set_text (GTK_ENTRY(lee15), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee15), TRUE);
 
 		lehbox16 = gtk_hbox_new (TRUE, 0);
@@ -431,7 +442,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee16 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee16, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox16), lee16, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee16), w[U2]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[U2]);
+		gtk_entry_set_text (GTK_ENTRY(lee16), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee16), TRUE);
 
 		lehbox17 = gtk_hbox_new (TRUE, 0);
@@ -445,7 +457,8 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lee17 = gtk_entry_new ();
 		gtk_widget_set_size_request (lee17, 50, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox17), lee17, FALSE, FALSE, 0);
-		gtk_entry_set_text (GTK_ENTRY(lee17), w[REMARKS]);
+		temp = g_strdup_printf ("%d", preferences.logcwidths2[REMARKS]);
+		gtk_entry_set_text (GTK_ENTRY(lee17), temp);
 		gtk_entry_set_activates_default (GTK_ENTRY (lee17), TRUE);
 
 		endhbox = lookup_widget (mainwindow, "endhbox");
@@ -636,16 +649,23 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 				}
 			}
 
-			/* sort the fields array and copy it back */
-			g_qsort_with_data (fields, QSO_FIELDS, sizeof (gint), (GCompareDataFunc) compare_fields, NULL);
-			/* copy the array, ignore prepending zero's */
+			/* sort the fields array */
+			g_qsort_with_data (fields, QSO_FIELDS, sizeof (gint),
+				(GCompareDataFunc) compare_fields, NULL);
+
+			/*
+			 * copy the array, ignore prepending zero's 
+			 * which have been added by qsort 
+			 */
 			for (i = 0; i < QSO_FIELDS; i++)
 				if (fields[i] != 0) break;
 			for (j = 0; j < columns; j++)
 				logw->logfields[j] = fields[j + i];
+
 			/* fill up with zero's */
 			for (j = columns; j < QSO_FIELDS; j++)
 				logw->logfields[j] = 0;
+
 			logw->columns = columns;
 
 			temp = gtk_editable_get_chars (GTK_EDITABLE (leentry15), 0, -1);
@@ -675,69 +695,62 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		}
 
 		/* now set column widths for all visible logs if changed */
-		w[NR] = gtk_editable_get_chars (GTK_EDITABLE (lee0), 0, -1);
-		w[DATE] = gtk_editable_get_chars (GTK_EDITABLE (lee1), 0, -1);
-		w[GMT] = gtk_editable_get_chars (GTK_EDITABLE (lee2), 0, -1);
-		w[GMTEND] = gtk_editable_get_chars (GTK_EDITABLE (lee3), 0, -1);
-		w[CALL] = gtk_editable_get_chars (GTK_EDITABLE (lee4), 0, -1);
-		w[BAND] = gtk_editable_get_chars (GTK_EDITABLE (lee5), 0, -1);
-		w[MODE] = gtk_editable_get_chars (GTK_EDITABLE (lee6), 0, -1);
-		w[RST] = gtk_editable_get_chars (GTK_EDITABLE (lee7), 0, -1);
-		w[MYRST] = gtk_editable_get_chars (GTK_EDITABLE (lee8), 0, -1);
-		w[AWARDS] = gtk_editable_get_chars (GTK_EDITABLE (lee18), 0, -1);
-		w[QSLIN] = gtk_editable_get_chars (GTK_EDITABLE (lee9_10), 0, -1);
-		w[QSLOUT] = gtk_editable_get_chars (GTK_EDITABLE (lee9_10), 0, -1);
-		w[POWER] = gtk_editable_get_chars (GTK_EDITABLE (lee11), 0, -1);
-		w[NAME] = gtk_editable_get_chars (GTK_EDITABLE (lee12), 0, -1);
-		w[QTH] = gtk_editable_get_chars (GTK_EDITABLE (lee13), 0, -1);
-		w[LOCATOR] = gtk_editable_get_chars (GTK_EDITABLE (lee14), 0, -1);
-		w[U1] = gtk_editable_get_chars (GTK_EDITABLE (lee15), 0, -1);
-		w[U2] = gtk_editable_get_chars (GTK_EDITABLE (lee16), 0, -1);
-		w[REMARKS] = gtk_editable_get_chars (GTK_EDITABLE (lee17), 0, -1);
-		if (wchanged(w))
+		preferences.logcwidths2[NR] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee0), 0, -1));
+		preferences.logcwidths2[DATE] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee1), 0, -1));
+		preferences.logcwidths2[GMT] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee2), 0, -1));
+		preferences.logcwidths2[GMTEND] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee3), 0, -1));
+		preferences.logcwidths2[CALL] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee4), 0, -1));
+		preferences.logcwidths2[BAND] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee5), 0, -1));
+		preferences.logcwidths2[MODE] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee6), 0, -1));
+		preferences.logcwidths2[RST] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee7), 0, -1));
+		preferences.logcwidths2[MYRST] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee8), 0, -1));
+		preferences.logcwidths2[AWARDS] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee18), 0, -1));
+		preferences.logcwidths2[QSLIN] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee9_10), 0, -1));
+		preferences.logcwidths2[QSLOUT] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee9_10), 0, -1));
+		preferences.logcwidths2[POWER] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee11), 0, -1));
+		preferences.logcwidths2[NAME] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee12), 0, -1));
+		preferences.logcwidths2[QTH] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee13), 0, -1));
+		preferences.logcwidths2[LOCATOR] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee14), 0, -1));
+		preferences.logcwidths2[U1] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee15), 0, -1));
+		preferences.logcwidths2[U2] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee16), 0, -1));
+		preferences.logcwidths2[REMARKS] = atoi(gtk_editable_get_chars (GTK_EDITABLE (lee17), 0, -1));
+
+		for (i = 0; i < g_list_length (logwindowlist); i++)
 		{
-			for (i = 0; i < g_list_length (logwindowlist); i++)
+			logw = g_list_nth_data (logwindowlist, i);
+			for (j = 0; j < QSO_FIELDS; j++)
 			{
-				logw = g_list_nth_data (logwindowlist, i);
-				for (j = 0; j < QSO_FIELDS; j++)
+				column = gtk_tree_view_get_column (GTK_TREE_VIEW(logw->treeview), j);
+				if (j != NR)
 				{
-					column = gtk_tree_view_get_column
-						(GTK_TREE_VIEW(logw->treeview), j);
-					if (j != NR)
-					{
-						if (atoi(w[j]) > 19)
-							gtk_tree_view_column_set_fixed_width
-								(GTK_TREE_VIEW_COLUMN(column), atoi(w[j]));
-						else
-						{
-							gtk_tree_view_column_set_fixed_width
-								(GTK_TREE_VIEW_COLUMN(column), 20);
-							w[j] = g_strdup ("20");
-						}
-					}
+					if (preferences.logcwidths2[j] > 19)
+						gtk_tree_view_column_set_fixed_width
+							(GTK_TREE_VIEW_COLUMN(column), preferences.logcwidths2[j]);
 					else
 					{
-						if (atoi(w[j]) == 0)
-							gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
+						gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN(column), 20);
+						preferences.logcwidths2[j] = 20;
+					}
+				}
+				else
+				{
+					if (preferences.logcwidths2[j] == 0)
+						gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
+					else
+					{
+						gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
+						if (preferences.logcwidths2[j] > 19)
+							gtk_tree_view_column_set_fixed_width
+								(GTK_TREE_VIEW_COLUMN(column), preferences.logcwidths2[j]);
 						else
 						{
-							gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
-							if (atoi(w[j]) > 19)
-								gtk_tree_view_column_set_fixed_width
-									(GTK_TREE_VIEW_COLUMN(column), atoi(w[j]));
-							else
-							{
-								gtk_tree_view_column_set_fixed_width
-									(GTK_TREE_VIEW_COLUMN(column), 20);
-								w[j] = g_strdup ("20");
-							}
+							gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN(column), 20);
+							preferences.logcwidths2[j] = 20;
 						}
 					}
 				}
 			}
-			preferences.logcwidths2 = g_strjoinv (",", w);
 		}
-		g_strfreev (w);
 		gtk_widget_destroy (logeditor);
 	}
 }
