@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -42,7 +42,7 @@
 #include "gui_keys.h"
 #include "gui_logeditordialog.h"
 #include "gui_newlogdialog.h"
-#include "gui_printdialog.h"
+#include "gui_gtkprintdialog.h"
 #include "gui_preferencesdialog.h"
 #include "gui_saveasdialog.h"
 #include "gui_scorewindow.h"
@@ -57,19 +57,23 @@
 #include "gui_awards_was.h"
 #include "gui_awards_waz.h"
 #include "gui_awards_iota.h"
+#include "gui_awards_locator.h"
+#include "gui_countrymap.h"
 #include "support.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "gui_tracedialog.h"
 
 GtkUIManager *ui_manager;
 extern preferencestype preferences;
 
+#ifndef G_OS_WIN32
 static struct {
 	gchar *filename;
 	gchar *stock_id;
 } stock_icons[] = {
 	{ DATADIR"/pixmaps/xlog/cwdaemon.png", "xlog_stock_cwdaemon" },
 	{ DATADIR"/pixmaps/xlog/jigsaw.png", "xlog_stock_merge" },
+	{ DATADIR"/pixmaps/xlog/countrymap.png", "xlog_stock_map" },
 };
 
 static gint n_stock_icons = G_N_ELEMENTS (stock_icons);
@@ -97,6 +101,7 @@ register_my_stock_icons (void)
 	gtk_icon_factory_add_default (icon_factory);
 	g_object_unref (icon_factory);
 }
+#endif
 
 GtkWidget*
 create_mainwindow (void)
@@ -149,22 +154,23 @@ static GtkActionEntry entries[] =
   { "New", GTK_STOCK_NEW, N_("New..."), "<control>N", "New log", G_CALLBACK(on_menu_new_activate) },
   { "Open", GTK_STOCK_OPEN, N_("Open"), "<control>O", "Open a log", G_CALLBACK(on_menu_open_activate) },
   { "Print", GTK_STOCK_PRINT, N_("Print"), "<control>P", "Print log", G_CALLBACK(on_menu_print_activate) },
+  { "PageSetup", GTK_STOCK_PRINT_PREVIEW, N_("Page Setup"), "<control><shift>P", "Page setup for printing", G_CALLBACK(on_menu_pagesetup_activate) },
   { "Save", GTK_STOCK_SAVE, N_("Save"), "<control>S", "Save log", G_CALLBACK(on_menu_save_activate) },
   { "Save As", GTK_STOCK_SAVE_AS, N_("Save As..."), "<control><shift>S", "Save log as", G_CALLBACK(on_menu_saveas_activate) },
-  { "Close", GTK_STOCK_CLOSE, N_("Close"), "<control>W", "Close log", G_CALLBACK(on_menu_close_activate) },
-  { "Export", GTK_STOCK_SAVE_AS, N_("Export..."), "<control>E", "Save log as", G_CALLBACK(on_menu_export_activate) },
+  { "Close", GTK_STOCK_CLOSE, N_("Close"), "<control><shift>W", "Close log", G_CALLBACK(on_menu_close_activate) },
+  { "Export", GTK_STOCK_SAVE_AS, N_("Export..."), "<control>E", "Export a log", G_CALLBACK(on_menu_export_activate) },
   { "Import", GTK_STOCK_CONVERT, N_("Import..."), "<control>I", "Import a log", G_CALLBACK(on_menu_import_activate) },
   { "Merge", "xlog_stock_merge", N_("Merge"), "<control>M", "Merge logs", G_CALLBACK(on_menu_merge_activate) },
   { "Quit", GTK_STOCK_QUIT, N_("Quit"), "<control>Q", "Quit program", G_CALLBACK(on_menu_exit_activate) },
 
-  { "Add", GTK_STOCK_ADD, N_("Add"), "<control>A",
-		N_("Add a new QSO to the log [Ctrl-A]"), G_CALLBACK(on_abutton_clicked) },
+  { "Write", GTK_STOCK_ADD, N_("Write"), "<control>W",
+		N_("Write a QSO to the log [Ctrl-W]"), G_CALLBACK(on_abutton_clicked) },
   { "Clear All", GTK_STOCK_CLEAR, N_("Clear All"), "<control>Y",
 		"Clear all fields", G_CALLBACK(on_clearframe_activate) },
   { "Click All", GTK_STOCK_APPLY, N_("Click All"), "<control>K",
 		"Click all buttons", G_CALLBACK(on_clickall_activate) },
-  { "Add and Click All", GTK_STOCK_ADD, N_("Add and Click All"), "<control><shift>A",
-		"Add a new QSO to the log and Click All", G_CALLBACK(on_addclickall_activate) },
+  { "Write and Click All", GTK_STOCK_ADD, N_("Write and Click All"), "<control>space",
+		"Write a QSO to the log and Click All", G_CALLBACK(on_addclickall_activate) },
   { "Delete", GTK_STOCK_REMOVE, N_("Delete"), "<control>D",
 		N_("Delete a selected log entry [Ctrl-D]"), G_CALLBACK(on_dbutton_clicked) },
   { "Find", GTK_STOCK_FIND, N_("Find"), "<control>F",
@@ -172,6 +178,11 @@ static GtkActionEntry entries[] =
   { "Update", GTK_STOCK_REFRESH, N_("Update"), "<control>U",
 		N_("Update a modified log entry [Ctrl-U]"), G_CALLBACK(on_ubutton_clicked) },
 
+  { "CountryMap", "xlog_stock_map", N_("Country Map"), "<control><shift>M", "Show/hide the country map", G_CALLBACK(on_countrymap_activate) },
+#ifndef G_OS_WIN32
+  { "Keyer", "xlog_stock_cwdaemon", N_("Keyer"), "<control>R", "Activate keyer interface", G_CALLBACK(on_keyer_activate) },
+#endif
+
   { "Dupe Check", GTK_STOCK_COPY, N_("Dupe Check..."), "<control><shift>C", "Check the log(s) for dupes", G_CALLBACK(on_menu_dupecheck_activate) },
   { "Log Editor", GTK_STOCK_PROPERTIES, N_("Log Editor"), "<control><shift>E", "Format fields in the log", G_CALLBACK(on_menu_logeditor_activate) },
   { "Trace Hamlib", GTK_STOCK_EXECUTE, N_("Trace Hamlib"), "<control><shift>T", "Show hamlib debugging output", G_CALLBACK(on_trace_hamlib_activate) },
@@ -182,6 +193,8 @@ static GtkActionEntry entries[] =
   { "WAS", GTK_STOCK_INFO, "WAS", "<control>3", "WAS worked/confirmed", G_CALLBACK(on_awards_was_activate) },
   { "WAZ", GTK_STOCK_INFO, "WAZ", "<control>4", "WAZ worked/confirmed", G_CALLBACK(on_awards_waz_activate) },
   { "IOTA", GTK_STOCK_INFO, "IOTA", "<control>5", "IOTA worked/confirmed", G_CALLBACK(on_awards_iota_activate) },
+  { "Locator", GTK_STOCK_INFO, N_("Locator List"), "<control>6", "Locator worked/confirmed", G_CALLBACK(on_awards_locator_activate) },
+  { "LocatorMap", GTK_STOCK_INFO, N_("Locator Map"), "<control>7", "Locator worked/confirmed map", G_CALLBACK(on_awards_locatormap_activate) },
 
   { "Defaults", GTK_STOCK_INDEX, N_("Defaults"), "<control>L", "Default values to use for logging", G_CALLBACK(on_menu_defaults_activate) },
   { "Dialogs", GTK_STOCK_JUSTIFY_FILL, N_("Dialogs and Windows"), "<control>B", "Settings for dialogs and windows used", G_CALLBACK(on_menu_dialogs_activate) },
@@ -211,10 +224,9 @@ static GtkActionEntry entries[] =
 
 static GtkToggleActionEntry toggle_entries[] =
 {
-  { "Keyer", "xlog_stock_cwdaemon", N_("Keyer"), "<control>R", "Activate keyer interface", G_CALLBACK(on_keyer_activate) },
   { "Scoring", NULL, N_("Scoring Window"), "<control>J", "Show/hide the scoring window", G_CALLBACK(on_scoring_activate) },
   { "ShowToolbar", NULL, N_("Show Toolbar"), "<control>T", "Show/hide the toolbar", G_CALLBACK(on_view_toolbar_activate) },
-  { "WorkedBefore", NULL, N_("Worked Before"), "<control><shift>W", "Show/hide the worked before window", G_CALLBACK(on_menu_worked_activate) },
+  { "WorkedBefore", NULL, N_("Worked Before"), "<control><shift>B", "Show/hide the worked before window", G_CALLBACK(on_menu_worked_activate) },
 };
 
 static const char *ui_description =
@@ -226,32 +238,41 @@ static const char *ui_description =
 "		<separator name='sep1'/>"
 "		<menuitem action='Save'/>"
 "		<menuitem action='Save As'/>"
-"		<menuitem action='Print'/>"
-"		<menuitem action='Close'/>"
 "		<separator name='sep2'/>"
 "		<menuitem action='Export'/>"
 "		<menuitem action='Import'/>"
 "		<menuitem action='Merge'/>"
+#ifndef G_OS_WIN32
+"		<separator name='sep2b'/>"
+"		<menuitem action='PageSetup'/>"
+"		<menuitem action='Print'/>"
+#endif
 "		<separator name='sep3'/>"
+"		<menuitem action='Close'/>"
 "		<menuitem action='Quit'/>"
 "	 </menu>"
 "	 <menu action='EditMenu'>"
-"		<menuitem action='Add'/>"
+"		<menuitem action='Write'/>"
 "		<menuitem action='Update'/>"
 "		<menuitem action='Delete'/>"
 "		<separator name='sep4'/>"
 "		<menuitem action='Clear All'/>"
 "		<menuitem action='Click All'/>"
 "		<separator name='sep4a'/>"
-"		<menuitem action='Add and Click All'/>"
+"		<menuitem action='Write and Click All'/>"
 "		<separator name='sep5'/>"
 "		<menuitem action='Find'/>"
 "	 </menu>"
 "	 <menu action='OptionMenu'>"
+"		<menuitem action='CountryMap'/>"
+#ifndef G_OS_WIN32
 "		<menuitem action='Keyer'/>"
+#endif
+"		<separator name='sep5a'/>"
 "		<menuitem action='Scoring'/>"
-"		<menuitem action='ShowToolbar'/>"
 "		<menuitem action='WorkedBefore'/>"
+"		<separator name='sep5b'/>"
+"		<menuitem action='ShowToolbar'/>"
 "	 </menu>"
 "	 <menu action='ToolsMenu'>"
 "		<menuitem action='Dupe Check'/>"
@@ -265,6 +286,8 @@ static const char *ui_description =
 "		  <menuitem action='WAS'/>"
 "		  <menuitem action='WAZ'/>"
 "		  <menuitem action='IOTA'/>"
+"		  <menuitem action='Locator'/>"
+"		  <menuitem action='LocatorMap'/>"
 "		</menu>"
 "	 </menu>"
 "	 <menu action='TabsMenu'>"
@@ -300,13 +323,15 @@ static const char *ui_description =
 "	 </menu>"
 "  </menubar>"
 "  <toolbar name='ToolBar'>"
-"	 <toolitem action='Add'/>"
+"	 <toolitem action='Write'/>"
 "	 <toolitem action='Update'/>"
 "	 <toolitem action='Delete'/>"
 "  </toolbar>"
 "</ui>";
 
+#ifndef G_OS_WIN32
 	register_my_stock_icons ();
+#endif
 
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title (GTK_WINDOW (window), "xlog");
@@ -415,7 +440,9 @@ static const char *ui_description =
 	gtk_label_set_mnemonic_widget (GTK_LABEL(calllabel), callentry);
 	gtk_box_pack_start (GTK_BOX (callhbox), callentry, TRUE, TRUE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (callentry), 15);
-
+	GtkWidget *callbutton = gtk_button_new_with_mnemonic ("_?");
+	gtk_box_pack_start (GTK_BOX (callhbox), callbutton, FALSE, FALSE, 0);
+	gtk_widget_set_size_request (callbutton, 20, -1);
 	bandhbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), bandhbox, FALSE, FALSE, 0);
 	mhzhbox = gtk_hbox_new (FALSE, 0);
@@ -632,6 +659,8 @@ static const char *ui_description =
 		G_CALLBACK (on_callentry_insert_text), NULL);
 	g_signal_connect ((gpointer) callentry, "changed",
 		G_CALLBACK (on_callentry_changed), NULL);
+	g_signal_connect ((gpointer) callbutton, "clicked",
+		G_CALLBACK (on_callbutton_clicked), NULL);
 	g_signal_connect ((gpointer) locatorentry, "changed",
 		G_CALLBACK (on_locatorentry_changed), NULL);
 	b = gtk_text_view_get_buffer (GTK_TEXT_VIEW(remtv));
