@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -32,7 +32,7 @@
 
 #include "gui_mergedialog.h"
 #include "support.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "log.h"
 #include "utils.h"
 #include "gui_utils.h"
