@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -29,7 +29,7 @@
 #include "gui_netkeyer.h"
 #include "gui_utils.h"
 #include "utils.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "hamlib-utils.h"
 #include "main.h"
 
@@ -37,7 +37,6 @@ GtkWidget *keyerwindow = NULL;
 extern preferencestype preferences;
 extern programstatetype programstate;
 extern GtkWidget *mainwindow;
-extern GtkUIManager *ui_manager;
 keyerstatetype keyerstate;
 
 void savekeyer (void)
@@ -45,7 +44,6 @@ void savekeyer (void)
 	GtkWidget *f1entry, *f2entry, *f3entry, *f4entry, *f5entry,
 		*f6entry, *f7entry, *f8entry, *f9entry, *f10entry, *f11entry,
 		*f12entry, *cqentry, *spentry, *wpm;
-	gchar *temp;
 
 	wpm = lookup_widget (keyerwindow, "wpm");
 	f1entry = lookup_widget (keyerwindow, "f1entry");
@@ -64,78 +62,20 @@ void savekeyer (void)
 	spentry = lookup_widget (keyerwindow, "spentry");
 
 	preferences.cwspeed = gtk_spin_button_get_value (GTK_SPIN_BUTTON(wpm));
-	temp = gtk_editable_get_chars (GTK_EDITABLE (f1entry), 0, -1);
-	if (strlen (temp) == 0)
-		preferences.cwf1 = g_strdup ("^");
-	else
-		preferences.cwf1 = g_strdup (temp);
-	temp = gtk_editable_get_chars (GTK_EDITABLE (f2entry), 0, -1);
-	if (strlen (temp) == 0)
-		preferences.cwf2 = g_strdup ("^");
-	else
-		preferences.cwf2 = g_strdup (temp);
-	temp = gtk_editable_get_chars (GTK_EDITABLE (f3entry), 0, -1);
-	if (strlen (temp) == 0)
-		preferences.cwf3 = g_strdup ("^");
-	else
-		preferences.cwf3 = g_strdup (temp);
-	temp = gtk_editable_get_chars (GTK_EDITABLE (f4entry), 0, -1);
-	if (strlen (temp) == 0)
-		preferences.cwf4 = g_strdup ("^");
-	else
-		preferences.cwf4 = g_strdup (temp);
-	temp = gtk_editable_get_chars (GTK_EDITABLE (f5entry), 0, -1);
-	if (strlen (temp) == 0)
-		preferences.cwf5 = g_strdup ("^");
-	else
-		preferences.cwf5 = g_strdup (temp);
-	temp = gtk_editable_get_chars (GTK_EDITABLE (f6entry), 0, -1);
-	if (strlen (temp) == 0)
-		preferences.cwf6 = g_strdup ("^");
-	else
-		preferences.cwf6 = g_strdup (temp);
-	temp = gtk_editable_get_chars (GTK_EDITABLE (f7entry), 0, -1);
-	if (strlen (temp) == 0)
-		preferences.cwf7 = g_strdup ("^");
-	else
-		preferences.cwf7 = g_strdup (temp);
-	temp = gtk_editable_get_chars (GTK_EDITABLE (f8entry), 0, -1);
-	if (strlen (temp) == 0)
-		preferences.cwf8 = g_strdup ("^");
-	else
-		preferences.cwf8 = g_strdup (temp);
-	temp = gtk_editable_get_chars (GTK_EDITABLE (f9entry), 0, -1);
-	if (strlen (temp) == 0)
-		preferences.cwf9 = g_strdup ("^");
-	else
-		preferences.cwf9 = g_strdup (temp);
-	temp = gtk_editable_get_chars (GTK_EDITABLE (f10entry), 0, -1);
-	if (strlen (temp) == 0)
-		preferences.cwf10 = g_strdup ("^");
-	else
-		preferences.cwf10 = g_strdup (temp);
-	temp = gtk_editable_get_chars (GTK_EDITABLE (f11entry), 0, -1);
-	if (strlen (temp) == 0)
-		preferences.cwf11 = g_strdup ("^");
-	else
-		preferences.cwf11 = g_strdup (temp);
-	temp = gtk_editable_get_chars (GTK_EDITABLE (f12entry), 0, -1);
-	if (strlen (temp) == 0)
-		preferences.cwf12 = g_strdup ("^");
-	else
-		preferences.cwf12 = g_strdup (temp);
-	temp = gtk_editable_get_chars (GTK_EDITABLE (cqentry), 0, -1);
-	if (strlen (temp) == 0)
-		preferences.cwcq = g_strdup ("^");
-	else
-		preferences.cwcq = g_strdup (temp);
-	temp = gtk_editable_get_chars (GTK_EDITABLE (spentry), 0, -1);
-	if (strlen (temp) == 0)
-		preferences.cwsp = g_strdup ("^");
-	else
-		preferences.cwsp = g_strdup (temp);
-
-	g_free (temp);
+	preferences.cwf1 = gtk_editable_get_chars (GTK_EDITABLE (f1entry), 0, -1);
+	preferences.cwf2 = gtk_editable_get_chars (GTK_EDITABLE (f2entry), 0, -1);
+	preferences.cwf3 = gtk_editable_get_chars (GTK_EDITABLE (f3entry), 0, -1);
+	preferences.cwf4 = gtk_editable_get_chars (GTK_EDITABLE (f4entry), 0, -1);
+	preferences.cwf5 = gtk_editable_get_chars (GTK_EDITABLE (f5entry), 0, -1);
+	preferences.cwf6 = gtk_editable_get_chars (GTK_EDITABLE (f6entry), 0, -1);
+	preferences.cwf7 = gtk_editable_get_chars (GTK_EDITABLE (f7entry), 0, -1);
+	preferences.cwf8 = gtk_editable_get_chars (GTK_EDITABLE (f8entry), 0, -1);
+	preferences.cwf9 = gtk_editable_get_chars (GTK_EDITABLE (f9entry), 0, -1);
+	preferences.cwf10 = gtk_editable_get_chars (GTK_EDITABLE (f10entry), 0, -1);
+	preferences.cwf11 = gtk_editable_get_chars (GTK_EDITABLE (f11entry), 0, -1);
+	preferences.cwf12 = gtk_editable_get_chars (GTK_EDITABLE (f12entry), 0, -1);
+	preferences.cwcq = gtk_editable_get_chars (GTK_EDITABLE (cqentry), 0, -1);
+	preferences.cwsp = gtk_editable_get_chars (GTK_EDITABLE (spentry), 0, -1);
 
 	netkeyer_close ();
 }
@@ -145,14 +85,9 @@ static gboolean
 on_keyerwindow_delete_event (GtkWidget * widget, GdkEvent * event,
 	gpointer user_data)
 {
-	GtkWidget *keyermenu;
-
 	savekeyer ();
 	keyerwindow = NULL;
 
-	keyermenu = gtk_ui_manager_get_widget (ui_manager, "/MainMenu/OptionMenu/Keyer");
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(keyermenu), FALSE);
-
 	return FALSE;
 }
 
@@ -160,7 +95,7 @@ on_keyerwindow_delete_event (GtkWidget * widget, GdkEvent * event,
 void cw (GtkButton *button, gpointer user_data)
 {
 	GtkWidget *entry, *callentry, *count;
-	gchar *entryname, *sendstr, *call, *countstr;
+	gchar *entryname, *sendstr, *call, *countstr, *lastmsg;
 	gint i, result = 0;
 
 	entryname = g_strdup_printf("%sentry", (gchar *)user_data);
@@ -188,6 +123,15 @@ void cw (GtkButton *button, gpointer user_data)
 		g_free (countstr);
 
 		sendstr = my_strreplace (sendstr, "%", preferences.callsign);
+
+		lastmsg = get_last_msg ();
+		if (strlen (lastmsg) > 0)
+		{
+			sendstr = my_strreplace (sendstr, "~", lastmsg);
+			g_free (lastmsg);
+		}
+		else
+			sendstr = my_strreplace (sendstr, "~", "?");
 		if (strlen (call) > 0)
 		{
 			sendstr = my_strreplace (sendstr, "@", call);
@@ -363,11 +307,13 @@ void on_keyer_activate (GtkAction *action, gpointer user_data)
 	GtkTextBuffer *buffer;
 	gint result = 0;
 	gchar *speed;
-	gboolean status;
 
-	status = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	if (status)
+	if (keyerwindow)
 	{
+		gtk_window_present (GTK_WINDOW(keyerwindow));
+		return;
+	}
+
 	keyerwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title (GTK_WINDOW (keyerwindow), _("xlog - keyer"));
 	keyer_icon_pixbuf = create_pixbuf ("xlog-keyer.png");
@@ -569,34 +515,20 @@ void on_keyer_activate (GtkAction *action, gpointer user_data)
 	g_free (speed);
 
 	/* set entries for function keys */
-	if (g_ascii_strcasecmp (preferences.cwf1, "^"))
-		gtk_entry_set_text (GTK_ENTRY(f1entry), preferences.cwf1);
-	if (g_ascii_strcasecmp (preferences.cwf2, "^"))
-		gtk_entry_set_text (GTK_ENTRY(f2entry), preferences.cwf2);
-	if (g_ascii_strcasecmp (preferences.cwf3, "^"))
-		gtk_entry_set_text (GTK_ENTRY(f3entry), preferences.cwf3);
-	if (g_ascii_strcasecmp (preferences.cwf4, "^"))
-		gtk_entry_set_text (GTK_ENTRY(f4entry), preferences.cwf4);
-	if (g_ascii_strcasecmp (preferences.cwf5, "^"))
-		gtk_entry_set_text (GTK_ENTRY(f5entry), preferences.cwf5);
-	if (g_ascii_strcasecmp (preferences.cwf6, "^"))
-		gtk_entry_set_text (GTK_ENTRY(f6entry), preferences.cwf6);
-	if (g_ascii_strcasecmp (preferences.cwf7, "^"))
-		gtk_entry_set_text (GTK_ENTRY(f7entry), preferences.cwf7);
-	if (g_ascii_strcasecmp (preferences.cwf8, "^"))
-		gtk_entry_set_text (GTK_ENTRY(f8entry), preferences.cwf8);
-	if (g_ascii_strcasecmp (preferences.cwf9, "^"))
-		gtk_entry_set_text (GTK_ENTRY(f9entry), preferences.cwf9);
-	if (g_ascii_strcasecmp (preferences.cwf10, "^"))
-		gtk_entry_set_text (GTK_ENTRY(f10entry), preferences.cwf10);
-	if (g_ascii_strcasecmp (preferences.cwf11, "^"))
-		gtk_entry_set_text (GTK_ENTRY(f11entry), preferences.cwf11);
-	if (g_ascii_strcasecmp (preferences.cwf12, "^"))
-		gtk_entry_set_text (GTK_ENTRY(f12entry), preferences.cwf12);
-	if (g_ascii_strcasecmp (preferences.cwcq, "^"))
-		gtk_entry_set_text (GTK_ENTRY(cqentry), preferences.cwcq);
-	if (g_ascii_strcasecmp (preferences.cwsp, "^"))
-		gtk_entry_set_text (GTK_ENTRY(spentry), preferences.cwsp);
+	gtk_entry_set_text (GTK_ENTRY(f1entry), preferences.cwf1);
+	gtk_entry_set_text (GTK_ENTRY(f2entry), preferences.cwf2);
+	gtk_entry_set_text (GTK_ENTRY(f3entry), preferences.cwf3);
+	gtk_entry_set_text (GTK_ENTRY(f4entry), preferences.cwf4);
+	gtk_entry_set_text (GTK_ENTRY(f5entry), preferences.cwf5);
+	gtk_entry_set_text (GTK_ENTRY(f6entry), preferences.cwf6);
+	gtk_entry_set_text (GTK_ENTRY(f7entry), preferences.cwf7);
+	gtk_entry_set_text (GTK_ENTRY(f8entry), preferences.cwf8);
+	gtk_entry_set_text (GTK_ENTRY(f9entry), preferences.cwf9);
+	gtk_entry_set_text (GTK_ENTRY(f10entry), preferences.cwf10);
+	gtk_entry_set_text (GTK_ENTRY(f11entry), preferences.cwf11);
+	gtk_entry_set_text (GTK_ENTRY(f12entry), preferences.cwf12);
+	gtk_entry_set_text (GTK_ENTRY(cqentry), preferences.cwcq);
+	gtk_entry_set_text (GTK_ENTRY(spentry), preferences.cwsp);
 
 	GLADE_HOOKUP_OBJECT (keyerwindow, f1entry, "f1entry");
 	GLADE_HOOKUP_OBJECT (keyerwindow, f2entry, "f2entry");
@@ -655,13 +587,5 @@ void on_keyer_activate (GtkAction *action, gpointer user_data)
 
 	gtk_widget_grab_focus (wpm);
 	gtk_widget_show_all (keyerwindow);
-	}
-	else
-	{
-		if (keyerwindow)
-		{
-			gtk_widget_destroy (keyerwindow);
-			keyerwindow = NULL;
-		}
-	}
+	gtk_window_present (GTK_WINDOW(mainwindow));
 }
