@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -35,7 +35,7 @@
 #include "gui_warningdialog.h"
 #include "callbacks_mainwindow_menu.h"
 #include "support.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "log.h"
 #include "utils.h"
 #include "gui_utils.h"
@@ -88,7 +88,6 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gint i, response;
 	LOGDB *lp;
 	gboolean logopen = FALSE, logexist = FALSE;
-	GString *logs;
 
 	newlogdialog = gtk_dialog_new_with_buttons (_("xlog - new log"),
 		GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -135,29 +134,27 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 			}
 			if (!logopen)
 			{		/* check if the log exists and open it */
-				filename = g_strconcat (entry, ".xlog", NULL);
-				logs = getlogs (preferences.savedir, "*");
-				if (((logs->len) > 0) && (g_strrstr (logs->str, filename)))
+				filename = g_strconcat (preferences.savedir, G_DIR_SEPARATOR_S, entry, ".xlog", NULL);
+				if ((g_file_test (filename, G_FILE_TEST_EXISTS)))
 				{
 					logexist = TRUE;
-					filename = g_strconcat (preferences.savedir, G_DIR_SEPARATOR_S, entry, ".xlog", NULL);
 					lp = log_file_open (filename, TYPE_FLOG);
 					if (lp)
 					{
 						logwindow =	openlogwindow (lp, entry, programstate.logwindows++);
 						log_file_qso_foreach (lp, fillin_list, logwindow);
 						log_file_close (lp);
+						logwindow -> filename = g_strdup (filename);
 						logwindowlist =	g_list_append (logwindowlist, logwindow);
 						gtk_notebook_set_current_page(GTK_NOTEBOOK (mainnotebook), programstate.logwindows - 1);
 						set_qsoframe (logwindow);
 						set_tabs_menu ();
-						xlogbackupfile =	g_strconcat (filename, ".backup", NULL);
+						xlogbackupfile = g_strconcat (filename, ".backup", NULL);
 						savelog (logwindow, xlogbackupfile, TYPE_FLOG, 1, logwindow->qsos);
 						g_free (xlogbackupfile);
 						update_statusbar (_("A log with this name already exists"));
 					}
 					g_free (filename);
-					g_string_free (logs, TRUE);
 				}
 			}
 			if ((!logopen) && (!logexist))
