@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -35,7 +35,7 @@
 #include "gui_fontselectiondialog.h"
 #include "gui_pathselectiondialog.h"
 #include "support.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "callbacks_preferencesdialog.h"
 #include "gui_preferencesdialog.h"
 #include "utils.h"
@@ -81,12 +81,18 @@ qra_changed (GtkEntry *entry, gpointer data)
 
 		/* update widgets */
 		if (lat < 0.00)
+		{
+			lat = -1.0 * lat;
 			gtk_combo_box_set_active (GTK_COMBO_BOX (NScombo), 1);
+		}
 		else
 			gtk_combo_box_set_active (GTK_COMBO_BOX (NScombo), 0);
 
 		if (lon < 0.00)
+		{
+			lon = -1.0 * lon;
 			gtk_combo_box_set_active (GTK_COMBO_BOX (EWcombo), 1);
+		}
 		else
 			gtk_combo_box_set_active (GTK_COMBO_BOX (EWcombo), 0);
 
@@ -377,6 +383,30 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (unitshbox), unitscombo, TRUE, TRUE, 10);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (unitscombo), _("Kilometers"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (unitscombo), _("Miles"));
+	GtkWidget *lookupframe = gtk_frame_new (_("Lookup"));
+	gtk_box_pack_start (GTK_BOX (vboxpage3), lookupframe, FALSE, FALSE, 0);
+	GtkWidget *lookupvbox = gtk_vbox_new (FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (lookupframe), lookupvbox);
+	GtkWidget *labellookup = gtk_label_new
+(_("When clicking the \"?\" next to the callsign you can use your "
+	"internet browser to look it up. \"<call>\" in the lookup-URL will "
+	"be replaced by the callsign"));
+	gtk_label_set_line_wrap (GTK_LABEL (labellookup), TRUE);
+	gtk_box_pack_start (GTK_BOX (lookupvbox), labellookup, FALSE, FALSE, 0);
+	GtkWidget *lookupentry = gtk_entry_new ();
+	gtk_entry_set_text (GTK_ENTRY (lookupentry), preferences.openurl);
+	gtk_box_pack_start (GTK_BOX (lookupvbox), lookupentry, FALSE, FALSE, 0);
+	GtkWidget *keyerframe = gtk_frame_new (_("Keyer"));
+	gtk_box_pack_start (GTK_BOX (vboxpage3), keyerframe, FALSE, FALSE, 0);
+	GtkWidget *keyervbox = gtk_vbox_new (FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (keyerframe), keyervbox);
+	GtkWidget *labelkeyer = gtk_label_new
+(_("Initial exchange to use for \"~\" (see the manual for details)"));
+	gtk_label_set_line_wrap (GTK_LABEL (labelkeyer), TRUE);
+	gtk_box_pack_start (GTK_BOX (keyervbox), labelkeyer, FALSE, FALSE, 0);
+	GtkWidget *lastmsgentry = gtk_entry_new ();
+	gtk_entry_set_text (GTK_ENTRY (lastmsgentry), preferences.initlastmsg);
+	gtk_box_pack_start (GTK_BOX (keyervbox), lastmsgentry, FALSE, FALSE, 0);
 
 	preferenceslabel3 = gtk_label_new (_("Info"));
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (preferencesnotebook),
@@ -413,10 +443,16 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (devicehbox), devicelabel, TRUE, TRUE, 0);
 	devicecombo = gtk_combo_box_entry_new_text ();
 	gtk_box_pack_start (GTK_BOX (devicehbox), devicecombo, TRUE, TRUE, 0);
+#ifdef G_OS_WIN32
+	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "com1");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "com2");
+#else
 	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyS0");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyS1");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyS2");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyS3");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyUSB0");
+#endif
 	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "localhost");
 	gtk_entry_set_max_length (GTK_ENTRY (GTK_BIN(devicecombo)->child), 30);
 	gtk_entry_set_activates_default
@@ -494,7 +530,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		(GTK_BOX (hamlibvbox), hamlibseparator, FALSE, FALSE, 10);
 	digitshbox = gtk_hbox_new (TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (hamlibvbox), digitshbox, FALSE, FALSE, 0);
-	digitslabel = gtk_label_new (_("Round frequency to"));
+	digitslabel = gtk_label_new (_("Round frequency at digit"));
 	gtk_box_pack_start (GTK_BOX (digitshbox), digitslabel, FALSE, FALSE, 0);
 	digitscombo = gtk_combo_box_entry_new_text ();
 	gtk_box_pack_start (GTK_BOX (digitshbox), digitscombo, FALSE, FALSE, 0);
@@ -509,7 +545,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	GTK_WIDGET_UNSET_FLAGS
 		(GTK_EDITABLE (GTK_BIN(digitscombo)->child), GTK_CAN_FOCUS);
 	gtk_widget_set_size_request (digitscombo, 100, -1);
-	characterslabel = gtk_label_new (_("characters"));
+	characterslabel = gtk_label_new ("(0 = 1 Hz, 1 = 10 Hz, ...)");
 	gtk_box_pack_start (GTK_BOX (digitshbox), characterslabel, FALSE, FALSE, 0);
 
 	preferenceslabel4 = gtk_label_new ("Hamlib");
@@ -521,6 +557,9 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	vboxpage5 = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (preferencesnotebook), vboxpage5);
 
+	GtkWidget *reqlabel = gtk_label_new (_("Changing settings in the Logs section "
+		"of this page requires a restart!"));
+	gtk_box_pack_start (GTK_BOX (vboxpage5), reqlabel, FALSE, FALSE, 0);
 	logsframe = gtk_frame_new (_("Logs"));
 	gtk_box_pack_start (GTK_BOX (vboxpage5), logsframe, FALSE, FALSE, 0);
 	logsvbox = gtk_vbox_new (FALSE, 0);
@@ -551,6 +590,24 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_entry_set_max_length (GTK_ENTRY (logsentry), 90);
 	gtk_entry_set_activates_default (GTK_ENTRY (logsentry), TRUE);
 
+	logshseparator = gtk_hseparator_new ();
+	gtk_box_pack_start (GTK_BOX (logsvbox), logshseparator, TRUE, TRUE, 10);
+
+	GtkWidget *orderhbox = gtk_hbox_new (TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (logsvbox), orderhbox, FALSE, FALSE, 0);
+	GtkWidget *orderlabel = gtk_label_new 
+		(_("Load logs by"));
+	gtk_box_pack_start (GTK_BOX (orderhbox), orderlabel, FALSE, FALSE, 0);
+	GtkWidget *ordercombo = gtk_combo_box_entry_new_text ();
+	gtk_box_pack_start (GTK_BOX (orderhbox), ordercombo, FALSE, FALSE, 0);
+	gtk_combo_box_append_text
+		(GTK_COMBO_BOX (ordercombo), _("Time of last modification"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (ordercombo), _("Alphabet"));
+	gtk_editable_set_editable
+		(GTK_EDITABLE (GTK_BIN(ordercombo)->child), FALSE);
+	GTK_WIDGET_UNSET_FLAGS
+		(GTK_EDITABLE (GTK_BIN(ordercombo)->child), GTK_CAN_FOCUS);
+
 	savingframe = gtk_frame_new (_("Saving"));
 	gtk_box_pack_start (GTK_BOX (vboxpage5), savingframe, FALSE, FALSE, 0);
 	savingvbox = gtk_vbox_new (FALSE, 0);
@@ -575,7 +632,6 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (autosavehbox), autosavelabel, FALSE, FALSE, 0);
 	autosavecombo = gtk_combo_box_entry_new_text ();
 	gtk_box_pack_start (GTK_BOX (autosavehbox), autosavecombo, FALSE, FALSE, 0);
-	gtk_widget_set_size_request (autosavecombo, 100, -1);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "0");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "5");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "10");
@@ -679,6 +735,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 	/* logs to load at startup */
 	gtk_entry_set_text (GTK_ENTRY (logsentry), preferences.logstoload);
+	gtk_combo_box_set_active (GTK_COMBO_BOX(ordercombo), preferences.logorder);
 
 	/* callsign */
 	gtk_entry_set_text (GTK_ENTRY (callsignentry), preferences.callsign);
@@ -766,8 +823,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 	temp = g_strdup_printf ("%d", preferences.round);
 	gtk_entry_set_text (GTK_ENTRY (GTK_BIN(digitscombo)->child), temp);
-	if (g_ascii_strcasecmp (preferences.rigconf, "?"))
-		gtk_entry_set_text (GTK_ENTRY (rigsetconfentry), preferences.rigconf);
+	gtk_entry_set_text (GTK_ENTRY (rigsetconfentry), preferences.rigconf);
 
 	if (preferences.fcc == 1)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (fcccheckbutton), TRUE);
@@ -791,13 +847,13 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	/* location */
 	temp = g_strdup_printf ("%3.2f", preferences.latitude);
 	gtk_entry_set_text (GTK_ENTRY (latentry), temp);
-	if (preferences.NS == 1)
+	if (preferences.NS == 0)
 		gtk_combo_box_set_active (GTK_COMBO_BOX (NScombo), 0);
 	else
 		gtk_combo_box_set_active (GTK_COMBO_BOX (NScombo), 1);
 	temp = g_strdup_printf ("%3.2f", preferences.longitude);
 	gtk_entry_set_text (GTK_ENTRY (longentry), temp);
-	if (preferences.EW == 1)
+	if (preferences.EW == 0)
 		gtk_combo_box_set_active (GTK_COMBO_BOX (EWcombo), 0);
 	else
 		gtk_combo_box_set_active (GTK_COMBO_BOX (EWcombo), 1);
@@ -875,6 +931,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	GLADE_HOOKUP_OBJECT (preferencesdialog, longentry, "longentry");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, NScombo, "NScombo");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, EWcombo, "EWcombo");
+	GLADE_HOOKUP_OBJECT (preferencesdialog, lookupentry, "lookupentry");
 
 	/* page 3, hamlib */
 	GLADE_HOOKUP_OBJECT (preferencesdialog, hamlibframe, "hamlibframe");
@@ -974,6 +1031,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		/* get logs to load */
 		temp = gtk_editable_get_chars (GTK_EDITABLE (logsentry), 0, -1);
 		set_logstoload (temp);
+		preferences.logorder = gtk_combo_box_get_active (GTK_COMBO_BOX(ordercombo));
 
 		/* locator */
 		temp = gtk_editable_get_chars (GTK_EDITABLE (qthlocatorentry), 0, -1);
@@ -997,11 +1055,19 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		else
 			preferences.longitude = atof (temp);
 
-		preferences.NS = gtk_combo_box_get_active (GTK_COMBO_BOX (NScombo)) + 1;
-		preferences.EW = gtk_combo_box_get_active (GTK_COMBO_BOX (EWcombo)) + 1;
+		preferences.NS = gtk_combo_box_get_active (GTK_COMBO_BOX (NScombo));
+		preferences.EW = gtk_combo_box_get_active (GTK_COMBO_BOX (EWcombo));
 		preferences.units = gtk_combo_box_get_active 
 			(GTK_COMBO_BOX (unitscombo))  == 1 ? 0 : 1;
 
+		/* lookup URL */
+		temp = gtk_editable_get_chars (GTK_EDITABLE (lookupentry), 0, -1);
+		preferences.openurl = g_strdup (temp);
+
+		/* lastmessage for the keyer */
+		temp = gtk_editable_get_chars (GTK_EDITABLE (lastmsgentry), 0, -1);
+		preferences.initlastmsg = g_strdup (temp);
+
 		/* get the comma seperated list of modes and assign 
 		 * to the optionmenu */
 		temp = gtk_editable_get_chars (GTK_EDITABLE (modesentry), 0, -1);
@@ -1078,7 +1144,6 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 			pollstr = g_strdup ("0");
 		rigconf = gtk_editable_get_chars
 			(GTK_EDITABLE (rigsetconfentry), 0, -1);
-		if (strlen(rigconf) == 0) rigconf = g_strdup ("?");
 
 		if (hamlibyes)
 			hamlibwidgets =	whichhamlibwidgets (frequencyyesno, smeteryesno);
@@ -1114,8 +1179,12 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 			else
 			{
 				preferences.rigid = 1;
+#ifdef G_OS_WIN32
+				preferences.device = g_strdup ("com2");
+#else
 				preferences.device = g_strdup ("/dev/ttyS1");
-				preferences.rigconf = g_strdup ("?");
+#endif
+				preferences.rigconf = g_strdup ("");
 				preferences.polltime = 0;
 			}
 		}
