@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -31,7 +31,7 @@
 #include <gtk/gtk.h>
 #include <stdlib.h>
 
-#include "preferences.h"
+#include "cfg.h"
 #include "log.h"
 #include "gui_saveasdialog.h"
 #include "support.h"
@@ -103,7 +103,7 @@ on_menu_saveas_activate (GtkMenuItem * menuitem, gpointer user_data)
 				gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook)));
 			if (lowqso > highqso || highqso > logwindow->qsos)
 update_statusbar(_("Cannot save log: invalid entry for first and/or last QSO"));
-			else if (!fileexist (sellog))
+			else if (!g_file_test(sellog, G_FILE_TEST_EXISTS))
 			{
 				savelog (logwindow, sellog, TYPE_FLOG, lowqso, highqso);
 				temp = g_strdup_printf (_("Log saved to %s"), sellog);
