@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -26,7 +26,7 @@
 
 #include <gtk/gtk.h>
 #include "support.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "gui_scorewindow.h"
 #include "xlog_enum.h"
 #include "dxcc.h"
@@ -74,6 +74,7 @@ notebook_append_awardpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook, co
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING);
 	awardtreeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(awardmodel));
+	gtk_tree_view_set_search_column (GTK_TREE_VIEW (awardtreeview), -1);
 	g_object_unref (G_OBJECT (awardmodel));
 	gtk_container_add (GTK_CONTAINER (scrolledwindow), awardtreeview);
 
@@ -83,175 +84,175 @@ notebook_append_awardpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook, co
 		("0.136", renderer, "text", BAND_2190, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_2190] - 48);
+		(column, preferences.scoringbands[BAND_2190]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("1.8", renderer, "text", BAND_160, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_160] - 48);
+		(column, preferences.scoringbands[BAND_160]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("3.5", renderer, "text", BAND_80, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_80] - 48);
+		(column, preferences.scoringbands[BAND_80]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("5.2", renderer, "text", BAND_60, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_60] - 48);
+		(column, preferences.scoringbands[BAND_60]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("7", renderer, "text", BAND_40, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_40] - 48);
+		(column, preferences.scoringbands[BAND_40]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("10", renderer, "text", BAND_30, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_30] - 48);
+		(column, preferences.scoringbands[BAND_30]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("14", renderer, "text", BAND_20, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_20] - 48);
+		(column, preferences.scoringbands[BAND_20]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("18", renderer, "text", BAND_17, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_17] - 48);
+		(column, preferences.scoringbands[BAND_17]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("21", renderer, "text", BAND_15, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_15] - 48);
+		(column, preferences.scoringbands[BAND_15]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("24", renderer, "text", BAND_12, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_12] - 48);
+		(column, preferences.scoringbands[BAND_12]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("28", renderer, "text", BAND_10, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_10] - 48);
+		(column, preferences.scoringbands[BAND_10]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("50", renderer, "text", BAND_6, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_6] - 48);
+		(column, preferences.scoringbands[BAND_6]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("70", renderer, "text", BAND_4, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_4] - 48);
+		(column, preferences.scoringbands[BAND_4]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("144", renderer, "text", BAND_2, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_2] - 48);
+		(column, preferences.scoringbands[BAND_2]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("222", renderer, "text", BAND_125CM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_125CM] - 48);
+		(column, preferences.scoringbands[BAND_125CM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("420", renderer, "text", BAND_70CM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_70CM] - 48);
+		(column, preferences.scoringbands[BAND_70CM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("902", renderer, "text", BAND_33CM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_33CM] - 48);
+		(column, preferences.scoringbands[BAND_33CM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("1240", renderer, "text", BAND_23CM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_23CM] - 48);
+		(column, preferences.scoringbands[BAND_23CM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("2300", renderer, "text", BAND_13CM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_13CM] - 48);
+		(column, preferences.scoringbands[BAND_13CM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("3300", renderer, "text", BAND_9CM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_9CM] - 48);
+		(column, preferences.scoringbands[BAND_9CM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("5650", renderer, "text", BAND_6CM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_6CM] - 48);
+		(column, preferences.scoringbands[BAND_6CM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("10000", renderer, "text", BAND_3CM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_3CM] - 48);
+		(column, preferences.scoringbands[BAND_3CM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("24000", renderer, "text", BAND_12HMM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_12HMM] - 48);
+		(column, preferences.scoringbands[BAND_12HMM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("47000", renderer, "text", BAND_6MM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_6MM] - 48);
+		(column, preferences.scoringbands[BAND_6MM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("75500", renderer, "text", BAND_4MM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_4MM] - 48);
+		(column, preferences.scoringbands[BAND_4MM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("120000", renderer, "text", BAND_2HMM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_2HMM] - 48);
+		(column, preferences.scoringbands[BAND_2HMM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("142000", renderer, "text", BAND_2MM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_2MM] - 48);
+		(column, preferences.scoringbands[BAND_2MM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("241000", renderer, "text", BAND_1MM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_1MM] - 48);
+		(column, preferences.scoringbands[BAND_1MM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("300000", renderer, "text", BAND_SUBMM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_SUBMM] - 48);
+		(column, preferences.scoringbands[BAND_SUBMM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("All", renderer, "text", MAX_BANDS, NULL);
@@ -339,6 +340,7 @@ create_scorewindow (void)
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (scorewindow), hbox);
 	vboxleft = gtk_vbox_new (FALSE, 0);
+	gtk_widget_set_size_request (vboxleft, 200, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), vboxleft, FALSE, FALSE, 0);
 
 	/* locator information frame */
@@ -376,11 +378,12 @@ create_scorewindow (void)
 	gtk_box_pack_start (GTK_BOX (dxccvbox), dxcclabel4, FALSE, FALSE, 0);
 	dxcclabel5 = gtk_label_new ("");
 	gtk_box_pack_start (GTK_BOX (dxccvbox), dxcclabel5, FALSE, FALSE, 0);
+	
 	dxccframelabel = gtk_label_new (NULL);
 	gtk_label_set_markup (GTK_LABEL (dxccframelabel), "<b>DXCC</b>");
 	gtk_frame_set_label_widget (GTK_FRAME (dxccframe), dxccframelabel);
 	gtk_label_set_line_wrap (GTK_LABEL (dxcclabel1), TRUE);
-	gtk_widget_set_size_request (dxcclabel1, 200, 60);
+	gtk_widget_set_size_request (dxcclabel1, -1, 60);
 	gtk_label_set_justify (GTK_LABEL (dxcclabel1), GTK_JUSTIFY_CENTER);
 
 	/* top */
@@ -405,6 +408,7 @@ create_scorewindow (void)
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING);
 	countrytreeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(model));
+	gtk_tree_view_set_search_column (GTK_TREE_VIEW (countrytreeview), -1);
 	g_object_unref (G_OBJECT (model));
 	gtk_container_add (GTK_CONTAINER (scrolledwindow), countrytreeview);
 	renderer = gtk_cell_renderer_text_new ();
@@ -418,176 +422,176 @@ create_scorewindow (void)
 		("0.136", renderer, "text", BAND_2190 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_2190] - 48);
+		(column, preferences.scoringbands[BAND_2190]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("1.8", renderer, "text", BAND_160 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_160] - 48);
+		(column, preferences.scoringbands[BAND_160]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("3.5", renderer, "text", BAND_80 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_80] - 48);
+		(column, preferences.scoringbands[BAND_80]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("5.2", renderer, "text", BAND_60 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_60] - 48);
+		(column, preferences.scoringbands[BAND_60]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("7", renderer, "text", BAND_40 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_40] - 48);
+		(column, preferences.scoringbands[BAND_40]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("10", renderer, "text", BAND_30 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_30] - 48);
+		(column, preferences.scoringbands[BAND_30]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("14", renderer, "text", BAND_20 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_20] - 48);
+		(column, preferences.scoringbands[BAND_20]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("18", renderer, "text", BAND_17 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_17] - 48);
+		(column, preferences.scoringbands[BAND_17]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("21", renderer, "text", BAND_15 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_15] - 48);
+		(column, preferences.scoringbands[BAND_15]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("24", renderer, "text", BAND_12 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_12] - 48);
+		(column, preferences.scoringbands[BAND_12]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("28", renderer, "text", BAND_10 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_10] - 48);
+		(column, preferences.scoringbands[BAND_10]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("50", renderer, "text", BAND_6 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_6] - 48);
+		(column, preferences.scoringbands[BAND_6]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("70", renderer, "text", BAND_4 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_4] - 48);
+		(column, preferences.scoringbands[BAND_4]);
 
 	gtk_tree_view_column_set_visible (column, FALSE);
 	column = gtk_tree_view_column_new_with_attributes
 		("144", renderer, "text", BAND_2 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_2] - 48);
+		(column, preferences.scoringbands[BAND_2]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("222", renderer, "text", BAND_125CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_125CM] - 48);
+		(column, preferences.scoringbands[BAND_125CM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("420", renderer, "text", BAND_70CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_70CM] - 48);
+		(column, preferences.scoringbands[BAND_70CM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("902", renderer, "text", BAND_33CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_33CM] - 48);
+		(column, preferences.scoringbands[BAND_33CM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("1240", renderer, "text", BAND_23CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_23CM] - 48);
+		(column, preferences.scoringbands[BAND_23CM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("2300", renderer, "text", BAND_13CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_13CM] - 48);
+		(column, preferences.scoringbands[BAND_13CM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("3300", renderer, "text", BAND_9CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_9CM] - 48);
+		(column, preferences.scoringbands[BAND_9CM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("5650", renderer, "text", BAND_6CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_6CM] - 48);
+		(column, preferences.scoringbands[BAND_6CM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("10000", renderer, "text", BAND_3CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_3CM] - 48);
+		(column, preferences.scoringbands[BAND_3CM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("24000", renderer, "text", BAND_12HMM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_12HMM] - 48);
+		(column, preferences.scoringbands[BAND_12HMM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("47000", renderer, "text", BAND_6MM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_6MM] - 48);
+		(column, preferences.scoringbands[BAND_6MM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("75500", renderer, "text", BAND_4MM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_4MM] - 48);
+		(column, preferences.scoringbands[BAND_4MM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("120000", renderer, "text", BAND_2HMM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_2HMM] - 48);
+		(column, preferences.scoringbands[BAND_2HMM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("142000", renderer, "text", BAND_2MM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_2MM] - 48);
+		(column, preferences.scoringbands[BAND_2MM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("241000", renderer, "text", BAND_1MM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_1MM] - 48);
+		(column, preferences.scoringbands[BAND_1MM]);
 
 	column = gtk_tree_view_column_new_with_attributes
 		("300000", renderer, "text", BAND_SUBMM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_visible
-		(column, preferences.scoringbands[BAND_SUBMM] - 48);
+		(column, preferences.scoringbands[BAND_SUBMM]);
 
 	awardscount = NB_AWARDS;
 
