@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -29,16 +29,14 @@
  */
 
 #include <gtk/gtk.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <unistd.h>
-#include <stdio.h>
+#include <glib/gstdio.h>
 #include <hamlib/rig.h>
 
 #include "gui_tracedialog.h"
 #include "gui_warningdialog.h"
 #include "support.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "hamlib-utils.h"
 
 typedef struct
@@ -68,7 +66,7 @@ stop_tracing (void)
 	dup2 (saved_fd, STDERR_FILENO);
 	close (saved_fd);
 #ifndef __NetBSD__
-#ifndef WIN32
+#ifndef G_OS_WIN32
 	stderr = fdopen (STDERR_FILENO, "w");
 #endif
 #endif
@@ -92,7 +90,7 @@ static int fileupdated(void)
 
 	if (finfo.filename) 
 	{
-		status = stat (finfo.filename, &s);
+		status = g_stat (finfo.filename, &s);
 			if (finfo.modified != s.st_mtime) 
 				return 1;
 	}
@@ -112,7 +110,7 @@ updatetrace (gpointer data)
 	fflush(stderr);
 	if (fileupdated ()) 
 		{
-			if ((fd = fopen(finfo.filename, "r"))) 
+			if ((fd = g_fopen(finfo.filename, "r"))) 
 				{ 
 					buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (data));
 					gtk_text_buffer_get_bounds (buffer, &start, &end);
