@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -31,14 +31,14 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <stdio.h>
 #include <glib.h>
 #include <ctype.h>
 #include <time.h>
+#include <glib/gstdio.h>
 
 #include "logfile.h"
-#include "preferences.h"
-#include "wwl.h"
+#include "../cfg.h"
+#include "../wwl.h"
 
 extern preferencestype preferences;
 
@@ -79,7 +79,7 @@ edi_open (LOGDB * handle)
 {
 	FILE *fp;
 
-	fp = fopen (handle->path, "r");
+	fp = g_fopen (handle->path, "r");
 	if (!fp)
 		return -1;
 	handle->priv = (gpointer) fp;
@@ -99,7 +99,7 @@ edi_create (LOGDB * handle)
 {
 	FILE *fp;
 
-	fp = fopen (handle->path, "w");
+	fp = g_fopen (handle->path, "w");
 	if (!fp)
 		return -1;
 	handle->priv = (gpointer) fp;
