@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -25,16 +25,14 @@
  */
 
 #include <stdlib.h>
-#include <stdio.h>
 #include <unistd.h>
-#include <sys/stat.h>
-#include <sys/types.h>
 #include <errno.h>
 #include <time.h>
 #include <locale.h>
 #include <gtk/gtk.h>
 #include <string.h>
 #include <hamlib/rig.h>
+#include <glib/gstdio.h>
 
 #if HAVE_SYS_IPC_H
 #include <sys/ipc.h>
@@ -51,7 +49,7 @@
 #include "callbacks_mainwindow_menu.h"
 #include "callbacks_mainwindow_qsoframe.h"
 #include "callbacks_mainwindow.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "log.h"
 #include "utils.h"
 #include "dxcc.h"
@@ -70,20 +68,19 @@ GList *logwindowlist = NULL;
 GdkColormap *colormap;
 GIOChannel *channel;
 
-static gboolean openhere = FALSE;
-static GString *logs;
-
 extern GtkWidget *b4window, *scorewindow;
 extern preferencestype preferences;
 extern remotetype remote;
 extern gint server_sockfd;
 extern GtkUIManager *ui_manager;
+extern GtkPrintSettings *print_settings;
+extern GtkPageSetup *print_page_setup;
 
 /* command line options */
 static void
 parsecommandline (int argc, char *argv[])
 {
-	gint i, p;
+	gint p;
 	gchar *versionstr;
 
 	while ((p = getopt (argc, argv, "hv")) != -1)
@@ -106,16 +103,6 @@ parsecommandline (int argc, char *argv[])
 				exit (0);
 		}
 	}
-	if (argc > 1)
-	{
-		openhere = TRUE;
-		logs = g_string_new ("");
-		for (i = 1; i < argc; i++)
-		{
-			g_string_append (logs, argv[i]);
-			g_string_append_c (logs, '\n');
-		}
-	}
 }
 
 /* see if we can create the ~/.xlog directory */
@@ -128,13 +115,9 @@ xlogdircheck (void)
 	g_string_printf (packagedir, "%s.", G_DIR_SEPARATOR_S);
 	g_string_append (packagedir, PACKAGE);
 	xlogdir = g_strconcat (g_get_home_dir (), packagedir->str, NULL);
-	if (stat (xlogdir, &statdir) == -1)
+	if (g_stat (xlogdir, &statdir) == -1)
 		{
-#ifdef WIN32
-			if (mkdir (xlogdir) == -1)
-#else
-			if (mkdir (xlogdir, S_IRUSR | S_IWUSR | S_IXUSR) == -1)
-#endif
+			if (g_mkdir (xlogdir, S_IRUSR | S_IWUSR | S_IXUSR) == -1)
 				g_error (_("Creating ~%s directory."), packagedir->str);
 			else
 				show_setupdialog();
@@ -166,16 +149,44 @@ setdefaultstate (void)
 	programstate.dupecheck = 0;
 	programstate.notdupecheckmode = FALSE;
 	programstate.notdupecheckband = FALSE;
+	programstate.px = g_strdup("");
 }
 
 static gboolean
 check_gtk_version (void)
 {
-	if ((gtk_major_version >= 2) && (gtk_minor_version >= 6))
+	if ((gtk_major_version >= 2) && (gtk_minor_version >= 12))
 		return FALSE;
 	return TRUE;
 }
 
+/* sort logs by last modified date or by alphabet */
+static gint sort_logs(gconstpointer a, gconstpointer b, gchar *savedir)
+{
+	gchar *log1 = g_strconcat
+		(savedir, G_DIR_SEPARATOR_S, *(gchar **)a, NULL);
+	gchar *log2 = g_strconcat
+		(savedir, G_DIR_SEPARATOR_S, *(gchar **)b, NULL);
+
+	gint diff;
+	if (preferences.logorder == 0)
+	{
+		struct stat stat1, stat2;
+		g_stat (log1, &stat1);
+		g_stat (log2, &stat2);
+		diff = stat1.st_mtime-stat2.st_mtime;
+	}
+	else
+	{
+		diff = strcmp (*(const char**)a, *(const char**)b);
+	}
+
+	g_free (log1);
+	g_free (log2);
+	return diff;
+}
+
+
 /* the fun starts here */
 gint
 main (int argc, char *argv[])
@@ -186,9 +197,10 @@ main (int argc, char *argv[])
 		*rstlabel, *rstbutton, *smeterhandlebox, *smeterdrawingarea,
 		*hpaned, *powerlabel, *powerbutton, *unknownlabel1,
 		*unknownlabel2, *handlebox, *menuitem;
-	gchar *xlogfile, *xlogbackupfile, *temp, *logstoload, **loglist = NULL;
+	gchar *temp;
+	
 	gint i, j, result;
-	gboolean showmainwindow = TRUE, logsfromprefs = FALSE, gtk_mismatch = FALSE;
+	gboolean showmainwindow = TRUE, logsfromlist = FALSE, gtk_mismatch = FALSE;
 	logtype *logwindow = NULL;
 	LOGDB *lp = NULL;
 	gboolean hamlibresult = FALSE;
@@ -196,28 +208,49 @@ main (int argc, char *argv[])
 
 	parsecommandline (argc, argv);
 
+#ifdef G_OS_WIN32
+	bindtextdomain (PACKAGE, "locale");
+	bind_textdomain_codeset (PACKAGE, "UTF-8");
+	textdomain (PACKAGE);
+#else
 #ifdef ENABLE_NLS
 	bindtextdomain (PACKAGE, XLOG_LOCALEDIR);
 	bind_textdomain_codeset (PACKAGE, "UTF-8");
 	textdomain (PACKAGE);
 #endif
+#endif
+
+	g_set_application_name ("xlog");
+
+#ifdef G_OS_WIN32
+	gchar *win32_dir = g_win32_get_package_installation_directory_of_module (NULL);
+	g_chdir (win32_dir);
+	g_free (win32_dir);
+#endif
 
-	gtk_set_locale ();
 	gtk_init (&argc, &argv);
 	gtk_mismatch = check_gtk_version ();
 	if (gtk_mismatch)
 	{
 		warningdialog (_("xlog - startup"),
-			_("xlog needs at least version 2.6 of the GTK+ libraries"), "gtk-dialog-error");
+			_("xlog needs at least version 2.12 of the GTK+ libraries"), "gtk-dialog-error");
 		exit (1);
 	}
 	setlocale(LC_NUMERIC, "C");
 
+#ifdef G_OS_WIN32
+	add_pixmap_directory ("pixmaps");
+#else
 	add_pixmap_directory
 		(DATADIR G_DIR_SEPARATOR_S "pixmaps" G_DIR_SEPARATOR_S "xlog");
+#endif
 
 	showmainwindow = xlogdircheck();
 	loadpreferences ();
+
+	print_settings = NULL;
+	print_page_setup = NULL;
+
 	loadhistory ();
 	mainwindow = create_mainwindow ();
 	if (!mainwindow) exit (1);
@@ -237,7 +270,8 @@ main (int argc, char *argv[])
 		g_warning (_("Could not read area table"));
 
 	qso = g_new0 (gchar *, QSO_FIELDS);
-	for (i = 0; i < QSO_FIELDS; i++)
+	qso[REMARKS] = g_new0 (gchar, 512);
+	for (i = 0; i < QSO_FIELDS - 1; i++)
 		qso[i] = g_new0 (gchar, 100);
 
 	/* logging should always be in GMT, shouldn't it? */
@@ -262,45 +296,63 @@ main (int argc, char *argv[])
 		preferences.savedir = g_strdup (xlogdir);
 
 	/* check for multiple *.xlog */
-	if (!openhere)
+	GPtrArray *xlogs;
+	if (argc == 1)
 	{
-		if (g_strrstr (preferences.logstoload, "*"))
+		if (g_strrstr (preferences.logstoload, "*")||
+			g_strrstr (preferences.logstoload, "?"))
 		/* read all logs of type xlog with a wildcard used */
-		logs = getlogs (preferences.savedir, preferences.logstoload);
+		xlogs = getxlogs (preferences.savedir, preferences.logstoload);
 		else
 		{ /* read logs from preferences.logstoload */
-			logstoload = g_strdup (preferences.logstoload);
-			g_strdelimit (logstoload, ",", '\n');
-			logs = g_string_new (logstoload);
-			g_free (logstoload);
-			logsfromprefs = TRUE;
+			gchar **loglist;
+			loglist = g_strsplit (preferences.logstoload, ",", -1);
+			xlogs = g_ptr_array_new ();
+			for (i = 0;; i++)
+			{
+				if (!loglist[i]) break;
+				g_strstrip (loglist[i]);
+				g_ptr_array_add (xlogs, g_strdup(loglist[i]));
+			}
+			g_strfreev (loglist);
+			logsfromlist = TRUE;
 		}
+		g_ptr_array_sort_with_data
+			(xlogs, (GCompareDataFunc) sort_logs, preferences.savedir);
+	}
+	else /* open logs from the command line */
+	{
+		xlogs = g_ptr_array_new ();
+		for (i = 1; i < argc; i++)
+			g_ptr_array_add (xlogs, g_strdup(argv[i]));
 	}
 
-	if ((logs->len) > 0)		/* flexible logs */
-		loglist = g_strsplit (logs->str, "\n", -1);
 
 	programstate.utf8error = FALSE;
 	j = 0;
-	for (i = 0;; i++)
+
+	if (xlogs) {
+	for (i = 0; i < xlogs->len; i++)
 	{
-		if (!loglist || !loglist[i] || (strlen(loglist[i]) == 0))
-			break;
-		if (logsfromprefs)
-			xlogfile = g_strconcat (preferences.savedir, G_DIR_SEPARATOR_S,
-				loglist[i], ".xlog", NULL);
+		gchar *logname = g_ptr_array_index (xlogs, i);
+		gchar *xlogfile;
+
+		if (logsfromlist)
+			xlogfile = g_strconcat
+				(preferences.savedir, G_DIR_SEPARATOR_S, logname, ".xlog", NULL);
 		else
 		{
-			if (!openhere)
+			if (argc == 1)
 				xlogfile = g_strconcat (preferences.savedir, G_DIR_SEPARATOR_S,
-					loglist[i], NULL);
+					logname, NULL);
 			else
-				xlogfile = g_strdup (loglist[i]);
+				xlogfile = g_strdup(logname);
 		}
+
 		lp = log_file_open (xlogfile, TYPE_FLOG);
 		if (lp)
 		{
-			logwindow = openlogwindow (lp, loglist[i], j);
+			logwindow = openlogwindow (lp, logname, j);
 			log_file_qso_foreach (lp, fillin_list, logwindow);
 			log_file_close (lp);
 			logwindow->filename = g_strdup (xlogfile);
@@ -314,6 +366,7 @@ main (int argc, char *argv[])
 			}
 			logwindowlist = g_list_append (logwindowlist, logwindow);
 			/* backup */
+			gchar *xlogbackupfile;
 			if (preferences.backup == 1)
 				xlogbackupfile = g_strconcat (xlogfile, ".backup", NULL);
 
@@ -325,12 +378,15 @@ main (int argc, char *argv[])
 			g_free (xlogbackupfile);
 			j++;
 		}
-		else g_warning (_("Can not open log %s"), xlogfile);
+		else
+		{
+			g_warning (_("Can not open log \"%s\""), xlogfile);
+		}
+		g_free (logname);
 		g_free (xlogfile);
-	}
+	} g_ptr_array_free (xlogs, TRUE);}
+	
 	programstate.logwindows = j;
-	g_strfreev (loglist);
-	g_string_free (logs, TRUE);
 	set_tabs_menu ();
 
 	g_signal_connect (G_OBJECT (mainnotebook), "switch_page",
@@ -399,6 +455,7 @@ main (int argc, char *argv[])
 		remotetimer = g_timeout_add (500, (GSourceFunc) remote_entry, NULL);
 #endif
 	/* Socket Server AF_INET Setup */
+#ifndef G_OS_WIN32
 	result = remote_socket_setup();
 	if (result == -1)
 	{
@@ -411,6 +468,7 @@ main (int argc, char *argv[])
 		channel = g_io_channel_unix_new (server_sockfd);
 		sockettimer = g_io_add_watch (channel, G_IO_IN, socket_entry, NULL);
 	}
+#endif
 
 	/* hamlib stuff */
 	mhzlabel = lookup_widget (mainwindow, "mhzlabel");
@@ -460,6 +518,7 @@ main (int argc, char *argv[])
 	gdk_window_move_resize (mainwindow->window, preferences.x,
 		preferences.y, preferences.width, preferences.height);
 
+	/* check all of the option menus and act upon */
 	handlebox = lookup_widget (mainwindow, "handlebox");
 	menuitem = gtk_ui_manager_get_widget (ui_manager, "/MainMenu/OptionMenu/ShowToolbar");
 	if (preferences.viewtoolbar == 1)
@@ -487,6 +546,7 @@ main (int argc, char *argv[])
 		gtk_widget_hide (b4window);
 	}
 
+	/* activate scoring */
 	scorewindow = create_scorewindow ();
 	menuitem = gtk_ui_manager_get_widget (ui_manager, "/MainMenu/OptionMenu/Scoring");
 	if (preferences.viewscoring == 1)
