@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -65,18 +65,20 @@
 #endif
 
 #include "remote.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "log.h"
 #include "utils.h"
 #include "support.h"
 #include "main.h"
 #include "hamlib-utils.h"
+#include "gui_warningdialog.h"
 
+#ifndef G_OS_WIN32
 /* Socket related includes */
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
-
+#endif
 
 msgtype msgbuf;
 remotetype remote;
@@ -126,8 +128,15 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 
 	if (type == 88 && entry && (strlen (entry) > 0))
 	{
-		logw = g_list_nth_data (logwindowlist,
-		gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook)));
+		gint page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook));
+		if (page == -1)
+		{
+			warningdialog (_("xlog - error"),
+			_("No log open while receiving remote data"),
+			"gtk-dialog-error");
+			return;
+		}
+		logw = g_list_nth_data (logwindowlist, page);
 
 		if (logw->readonly)
 		{
@@ -151,6 +160,8 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 		unknown2hbox = lookup_widget (mainwindow, "unknown2hbox");
 		awardshbox = lookup_widget (mainwindow, "awardshbox");
 
+		entry = my_strreplace (entry, "\n", " ");
+		entry = my_strreplace (entry, "\t", " ");
 		remoteinfo = g_strsplit (entry, "\1", 0);
 		for (;;)
 		{
@@ -555,6 +566,7 @@ remote_entry (void)
 	return 1;
 }
 
+#ifndef G_OS_WIN32
 static gboolean 
 tcp_client_activity (GIOChannel *source, GIOCondition cond, gpointer data)
 {
@@ -571,8 +583,9 @@ tcp_client_activity (GIOChannel *source, GIOCondition cond, gpointer data)
 	close (g_io_channel_unix_get_fd (source));
 	return FALSE;
 }
+#endif
 
-
+#ifndef G_OS_WIN32
 gboolean
 socket_entry (GIOChannel * channel, GIOCondition cond, gpointer data)
 {
@@ -594,8 +607,10 @@ socket_entry (GIOChannel * channel, GIOCondition cond, gpointer data)
 	}
 	return TRUE;
 }
+#endif
 
 /* Socket Server AF_INET Setup */
+#ifndef G_OS_WIN32
 gint
 remote_socket_setup (void)
 {
@@ -614,3 +629,4 @@ remote_socket_setup (void)
 		result = listen (server_sockfd, 5);
 	return result;
 }
+#endif
