@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -24,14 +24,19 @@
  * utils.c - assorted utilities
  */
 
+#ifdef WIN32
+#define NOGDI
+#include <windows.h>
+#endif
+
 #include <unistd.h>
 #include <stdlib.h>
-#include <stdio.h>
 #include <time.h>
 #include <errno.h>
 #include <sys/types.h>
 #include <string.h>
 #include <gtk/gtk.h>
+#include <glib/gstdio.h>
 #include <hamlib/rig.h>
 
 #if HAVE_SYS_IPC_H
@@ -46,7 +51,7 @@
 
 #include "log.h"
 #include "utils.h"
-#include "preferences.h"
+#include "cfg.h"
 #include "support.h"
 #include "history.h"
 #include "dxcc.h"
@@ -70,6 +75,56 @@ extern void *shareCall;
 extern GList *logwindowlist;
 extern GtkUIManager *ui_manager;
 
+#ifndef HAVE_INDEX
+#ifdef HAVE_STRCHR
+# define index(a,b) strchr(a,b)
+# define rindex(a,b) strrchr(a,b)
+#endif
+#endif
+
+#ifdef G_OS_WIN32
+int win32_fork (char *prog) 
+{
+    PROCESS_INFORMATION proc_info; 
+    STARTUPINFO start_info; 
+    int ret, err = 0;
+
+    ZeroMemory(&proc_info, sizeof proc_info);
+    ZeroMemory(&start_info, sizeof start_info);
+    start_info.cb = sizeof start_info; 
+
+    ret = CreateProcess(NULL, 
+			prog,          /* command line */
+			NULL,          /* process security attributes  */
+			NULL,          /* primary thread security attributes */ 
+			FALSE,         /* handles are inherited?  */
+			0,             /* creation flags  */
+			(LPVOID) NULL, /* NULL => use parent's environment  */
+			NULL,          /* use parent's current directory  */
+			&start_info,   /* receives STARTUPINFO */ 
+			&proc_info);   /* receives PROCESS_INFORMATION  */
+
+    return ret;
+}
+#endif
+
+void
+open_url (const char *link)
+{
+#ifdef G_OS_WIN32
+	gchar *command = g_strdup_printf ("iexplore.exe %s", link);
+	win32_fork (command);
+	g_free (command);
+#else
+	gchar *command[] = {"xdg-open", NULL, NULL};
+
+	command[1] = g_strdup (link);
+	g_spawn_async
+		(NULL, command, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, NULL);
+	g_free (command[1]);
+#endif
+}
+
 /* update the menu items of an optionmenu */
 void
 makebandoptionmenu (gchar *bands)
@@ -195,6 +250,7 @@ freestate (void)
 {
 	g_free (programstate.rigrst);
 	g_free (programstate.searchstr);
+	g_free (programstate.px);
 }
 
 /* free mem in prefs struct */
@@ -221,9 +277,6 @@ freeprefs (void)
 	g_free (preferences.defaultfreefield1);
 	g_free (preferences.defaultfreefield2);
 	g_free (preferences.defaultremarks);
-	g_free (preferences.b4columns2);
-	g_free (preferences.logcwidths2);
-	g_free (preferences.saveastsv2);
 	g_free (preferences.cwf1);
 	g_free (preferences.cwf2);
 	g_free (preferences.cwf3);
@@ -236,6 +289,8 @@ freeprefs (void)
 	g_free (preferences.cwf10);
 	g_free (preferences.cwf11);
 	g_free (preferences.cwf12);
+	g_free (preferences.openurl);
+	g_free (preferences.initlastmsg);
 }
 
 /* free mem in remote struct */
@@ -629,22 +684,6 @@ set_qsoframe (gpointer arg)
 	g_signal_emit_by_name (G_OBJECT (clearallmenu), "activate");
 }
 
-gboolean
-fileexist (gchar * path)
-{
-	FILE *fp = NULL;
-
-	fp = fopen (path, "r");
-
-	if (fp)
-		{
-			fclose (fp);
-			return (TRUE);
-		}
-	else
-		return (FALSE);
-}
-
 gchar *
 my_strreplace(const char *str, const char *delimiter, const char *replacement)
 {
