@@ -1,7 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -31,7 +31,7 @@
 #include "wwl.h"
 #include "support.h"
 #include "utils.h"
-#include "preferences.h"
+#include "cfg.h"
 
 extern preferencestype preferences;
 extern GtkWidget *scorewindow;
@@ -92,12 +92,12 @@ updatelocatorframe (gchar * locator)
 		{
 			if (preferences.units == 1)
 				locatorlabeltext = g_strdup_printf
-					(_("Distance: %d km, azimuth: %d deg"), p, l);
+					("%d km, %d\xc2\xb0", p, l);
 			else
 			{
 				m = (gint) (p / 1.609);
 				locatorlabeltext = g_strdup_printf
-					(_("Distance: %d m, azimuth: %d deg"), m, l);
+					("%d m, %d\xc2\xb0", m, l);
 			}
 		}
 		framelabeltext = g_strdup_printf ("<b>%s</b>", g_ascii_strup (locator, -1));
